C 29/03/98                                                      DWBA98  STDP-000
      SUBROUTINE STDP(FO,NQUA,ENE,XX,ISM,H,HS,LO,LT,IDMT,NT,MT)         STDP-001
C CALCULATION OF THE BOUND STATE WAVE FUNCTIONS.                        STDP-002
C INPUT:   NQUA(3) QUANTUM NUMBER  N (STARTING WITH 1), ANGULAR         STDP-003
C                  MOMENTUM L AND 2*(J-L).                              STDP-004
C          ENE     OSCILLATOR PARAMETER OR BINDING ENERGY.              STDP-005
C          ISM     NUMBER OF POINTS REQUIRED.                           STDP-006
C          H,HS    STEP SIZE WITH AND WITHOUT CORRECTION FOR RECOIL.    STDP-007
C          LO      LOGICAL CONTROLS LO(11)=.TRUE. FOR NON-LOCALITY      STDP-008
C                  CORRECTIONS FOR THE SOLUTIONS IN A POTENTIAL.        STDP-009
C                  LO(19) IS USED IN MEMO.                              STDP-010
C          LT(2)   LT(1)=.TRUE. SOLUTION IN A POTENTIAL.                STDP-011
C                  LT(2)=.TRUE. PRINT OUT THE FUNCTIONS OBTAINED.       STDP-012
C          IDMT    TOTAL DIMENSION OF THE WORKING AREA.                 STDP-013
C          NT      DIMENSION OF THE WORKING AREA XX.                    STDP-014
C OUTPUT:  FO(ISM)  WAVE FUNCTIONS.                                     STDP-015
C          MT      DIMENSION OF THE WORKING AREA USED.                  STDP-016
C WORKING AREA: XX(I,K)  FUNCTIONS FOR I=1.                             STDP-017
C                      CONSTANT PART OF THE POTENTIAL FOR I=2.          STDP-018
C                      CENTRAL POTENTIAL FORM FACTOR FOR I=3.           STDP-019
C THE CALCULATION IS CARRIED OUT WITH A QUARTER STEP SIZE AND K=4*ISM+1.STDP-020
C***********************************************************************STDP-021
      IMPLICIT REAL*8 (A-H,O-Z)                                         STDP-022
      LOGICAL LO(40),LT(2)                                              STDP-023
      DIMENSION XX(3,1),FO(1),NQUA(3)                                   STDP-024
      L=NQUA(2)                                                         STDP-025
      IF (LT(1)) GO TO 7                                                STDP-026
      N=NQUA(1)-1                                                       STDP-027
C COMPUTATION OF THE NORMALISATION OF LAGUERRE POLYNOMIALS              STDP-028
      A1=2.256758334191D0*ENE                                           STDP-029
      A3=L                                                              STDP-030
      IF (L.EQ.0) GO TO 2                                               STDP-031
      DO 1 I=1,L                                                        STDP-032
    1 A1=A1/(I+.5D0)                                                    STDP-033
    2 IF (N.EQ.0) GO TO 4                                               STDP-034
      DO 3 I=1,N                                                        STDP-035
      A2=I                                                              STDP-036
    3 A1=A1*(A2+A3+.5D0)/A2                                             STDP-037
    4 A1=DSQRT(A1*H/HS)                                                 STDP-038
C COMPUTATION OF LAGUERRE POLYNOMIALS                                   STDP-039
      RR=0.D0                                                           STDP-040
      DO 6 IS=1,ISM                                                     STDP-041
      RR=RR+H                                                           STDP-042
      X1=(ENE*RR)**2                                                    STDP-043
      X3=A1*DEXP(.5D0*((A3+1.D0)*DLOG(X1)-X1))                          STDP-044
      IF (N.EQ.0) GO TO 6                                               STDP-045
      X2=X3                                                             STDP-046
      DO  5 I=1,N                                                       STDP-047
      X2=2.D0*X2*(I-N-1)*X1/(I*(2.D0*(A3+I)+1.D0))                      STDP-048
    5 X3=X3+X2                                                          STDP-049
    6 FO(IS)=X3                                                         STDP-050
      IF (LT(2)) GO TO 28                                               STDP-051
      MT=0                                                              STDP-052
      RETURN                                                            STDP-053
C BOUND STATES IN A WOODS-SAXON POTENTIAL.                              STDP-054
    7 READ (5,1000) CM,ZZ,RC,RS,AS,CLS,RLS,ALS,ANL                      STDP-055
      KN=4*ISM                                                          STDP-056
      A4=H*.25D0                                                        STDP-057
      Y3=(CM-1.D0)**0.3333333333D0                                      STDP-058
      A2=Y3*RS                                                          STDP-059
      KR=A2/A4                                                          STDP-060
      IF (ENE.LE.0.D0) ENE=0.01D0                                       STDP-061
      WRITE (6,1001) (NQUA(I),I=1,3)                                    STDP-062
      WRITE (6,1002) KN,KR                                              STDP-063
      WRITE (6,1003) CM,ZZ,RC,RS,AS,CLS,RLS,ALS,ENE                     STDP-064
      IF (LO(11)) WRITE (6,1004) ANL                                    STDP-065
C OPTICAL POTENTIAL                                                     STDP-066
      X1=Y3*RC                                                          STDP-067
      A3=Y3*RLS                                                         STDP-068
      A1=A4*A4                                                          STDP-069
      Y1=(CM-1.D0)/CM                                                   STDP-070
      Y5=0.0478326D0*Y1*A1                                              STDP-071
      A5=ENE*Y5                                                         STDP-072
      RR=DSQRT(A5)/A4                                                   STDP-073
      X5=0.0344361325D0*Y1*ZZ/RR                                        STDP-074
      Y3=2.D0*CLS*Y5                                                    STDP-075
      Y4=-L                                                             STDP-076
      IF (NQUA(3).LE.0) Y4=L+1                                          STDP-077
      A6=Y4*(Y4-1.D0)*A1                                                STDP-078
      X4=X5*2.D0*A1*RR                                                  STDP-079
      X3=0.D0                                                           STDP-080
      K=KN+1                                                            STDP-081
      MT=6*K                                                            STDP-082
      IF (MT.GT.NT) CALL MEMO(IDMT,IDMT+MT-NT,NT,3,LO)                  STDP-083
      IF (LO(19)) GO TO 29                                              STDP-084
      DO 9 I=1,K                                                        STDP-085
      X3=X3+A4                                                          STDP-086
      X2=DEXP((X3-A3)/ALS)                                              STDP-087
      XX(2,I)=A6/(X3*X3)+Y4*Y3*X2/((1.D0+X2)**2*X3*ALS)+A5              STDP-088
      XX(3,I)=-1.D0/(1.D0+DEXP((X3-A2)/AS))                             STDP-089
      IF (X3.GT.X1) GO TO 8                                             STDP-090
      XX(2,I)=XX(2,I)+X4*(1.5D0-0.5D0*X3*X3/(X1*X1))/X1                 STDP-091
      GO TO 9                                                           STDP-092
    8 XX(2,I)=XX(2,I)+X4/X3                                             STDP-093
    9 CONTINUE                                                          STDP-094
C MATCHING CONDITIONS                                                   STDP-095
      X1=(X3-A4)*RR                                                     STDP-096
      X3=X3*RR                                                          STDP-097
      A6=A6/A1                                                          STDP-098
      N=5.D0*(X3-X1)+1.D0                                               STDP-099
      Y3=N                                                              STDP-100
      Y3=(X3-X1)/Y3                                                     STDP-101
      IG=1.D0/Y3                                                        STDP-102
      JG=MIN0(100,IG)                                                   STDP-103
      A5=Y3*Y3                                                          STDP-104
      A3=1.D0                                                           STDP-105
      DO 11 I=1,20                                                      STDP-106
      M=2*I*JG                                                          STDP-107
      A4=X3+Y3*M                                                        STDP-108
      Y1=DEXP(Y3)                                                       STDP-109
      Y4=0.5D0/Y3+0.5D0                                                 STDP-110
      Y2=(A6/(A4*A4)+2.D0*X5/A4+1.D0)*A5                                STDP-111
      DO 10 J=1,M                                                       STDP-112
      Y1=(2.D0+Y2/(1.D0-Y2/12.D0))-1.D0/Y1                              STDP-113
      A2=Y2                                                             STDP-114
      A4=A4-Y3                                                          STDP-115
      Y2=(A6/(A4*A4)+2.D0*X5/A4+1.D0)*A5                                STDP-116
      A1=Y1*(1.D0-A2/12.D0)/(1.D0-Y2/12.D0)                             STDP-117
   10 Y4=Y4/(A1*A1)+1.D0                                                STDP-118
      IF (DABS(Y1-A3).LT.0.1D-8*DABS(Y1-1.D0)) GO TO 12                 STDP-119
   11 A3=Y1                                                             STDP-120
      WRITE (6,1005)                                                    STDP-121
   12 Y4=(Y4-0.5D0)*Y3                                                  STDP-122
      WRITE (6,1006) I,M                                                STDP-123
      X2=1.D0/Y1                                                        STDP-124
      X3=1.D0                                                           STDP-125
      X4=Y2                                                             STDP-126
      DO 13 I=1,N                                                       STDP-127
      X1=X2                                                             STDP-128
      X2=X3                                                             STDP-129
      X3=(2.D0+X4/(1.D0-X4/12.D0))*X2-X1                                STDP-130
      A4=A4-Y3                                                          STDP-131
   13 X4=(A6/(A4*A4)+2.D0*X5/A4+1.D0)*A5                                STDP-132
      A3=X3*(1.D0-Y2/12.D0)/(1.D0-X4/12.D0)                             STDP-133
C STARTING VALUES                                                       STDP-134
      KS=2.D0+DSQRT(A6/12.D0)                                           STDP-135
      DO 14 I=1,KS                                                      STDP-136
   14 XX(1,I)=0.D0                                                      STDP-137
      XX(1,KS)=1.D0                                                     STDP-138
      IF (L.EQ.1) XX(1,KS-1)=-.2D0                                      STDP-139
      A4=35.D0                                                          STDP-140
      IK=2*NQUA(1)-2                                                    STDP-141
      IST=0                                                             STDP-142
      X1=0.D0                                                           STDP-143
      Y1=-1.D0                                                          STDP-144
      IN1=0                                                             STDP-145
      IN2=0                                                             STDP-146
C FIND THE CORRECT VALUE                                                STDP-147
   15 X3=X1+A4                                                          STDP-148
   16 IST=IST+1                                                         STDP-149
      IN3=0                                                             STDP-150
      X4=X3*Y5                                                          STDP-151
C  INTEGRATION TOWARDS THE OUTSIDE                                      STDP-152
      DO 17 I=KS,KR                                                     STDP-153
      X5=X4*XX(3,I-1)+XX(2,I-1)                                         STDP-154
      XX(1,I+1)=(2.D0+X5/(1.D0-X5/12.D0))*XX(1,I)-XX(1,I-1)             STDP-155
      IF (XX(1,I+1)*XX(1,I).LT.0.D0) IN3=IN3+2                          STDP-156
   17 CONTINUE                                                          STDP-157
      A1=XX(1,KR)                                                       STDP-158
      A2=XX(1,KR+1)                                                     STDP-159
      XX(1,KN+2)=1.D0                                                   STDP-160
      XX(1,KN+1)=A3*(1.D0-(X4*XX(3,KN)+XX(2,KN))/12.D0)/(1.D0-(X4*XX(3,KSTDP-161
     1N+1)+XX(2,KN+1))/12.D0)                                           STDP-162
C INTEGRATION TOWARDS THE INSIDE                                        STDP-163
      DO 18 I=KR,KN                                                     STDP-164
      J=KN+KR-I                                                         STDP-165
      X5=X4*XX(3,J)+XX(2,J)                                             STDP-166
      IF (XX(1,J+1)*XX(1,J+2).LT.0.D0) IN3=IN3+2                        STDP-167
   18 XX(1,J)=(2.D0+X5/(1.D0-X5/12.D0))*XX(1,J+1)-XX(1,J+2)             STDP-168
      Y3=A1/A2-XX(1,KR)/XX(1,KR+1)                                      STDP-169
      IF (Y3.GT.0.D0) IN3=IN3+1                                         STDP-170
      WRITE (6,1007) IST,IN3,X3,Y3                                      STDP-171
      IF (DABS(Y3).LE.1.D-10) GO TO 24                                  STDP-172
      IF (IN2.NE.0) GO TO 21                                            STDP-173
      IF (IN3.GT.IK) GO TO 19                                           STDP-174
      Y1=Y3                                                             STDP-175
      X1=X3                                                             STDP-176
      IN1=IN3                                                           STDP-177
      A4=X1                                                             STDP-178
      GO TO 15                                                          STDP-179
   19 WRITE (6,1008) IK,IN1,IN3                                         STDP-180
      X2=X3                                                             STDP-181
      IN2=IN3                                                           STDP-182
      Y2=Y3                                                             STDP-183
C INTERPOLATION OF THE SOLUTION                                         STDP-184
   20 X3=X1+0.5D0*(X2-X1)                                               STDP-185
      IF (IN2.EQ.IN1+1) X3=(Y1*X2-Y2*X1)/(Y1-Y2)                        STDP-186
      GO TO 16                                                          STDP-187
   21 X4=(Y1*Y2*X3*(X2-X1)+Y1*Y3*X2*(X1-X3)+Y2*Y3*X1*(X3-X2))/(Y1*Y2*(X2STDP-188
     1-X1)+Y1*Y3*(X1-X3)+Y2*Y3*(X3-X2))                                 STDP-189
      IF (IN2.GT.IN1+2) X4=1.D20                                        STDP-190
      IF (IN3.GT.IK) GO TO 22                                           STDP-191
      X1=X3                                                             STDP-192
      Y1=Y3                                                             STDP-193
      IN1=IN3                                                           STDP-194
      GO TO 23                                                          STDP-195
   22 X2=X3                                                             STDP-196
      Y2=Y3                                                             STDP-197
      IN2=IN3                                                           STDP-198
   23 IF ((X1-X4)*(X4-X2).LT.0.D0) GO TO 20                             STDP-199
      X3=X4                                                             STDP-200
      GO TO 16                                                          STDP-201
   24 Y3=A1/XX(1,KR)                                                    STDP-202
      K=KN+2                                                            STDP-203
      DO 25 I=KR,K                                                      STDP-204
   25 XX(1,I)=Y3*XX(1,I)                                                STDP-205
      Y1=0.D0                                                           STDP-206
      X4=16.D0*X3*Y5*(ANL/H)**2                                         STDP-207
      DO 26 I=1,KN                                                      STDP-208
      XX(1,I)=(XX(1,I)+10.D0*XX(1,I+1)+XX(1,I+2))/12.D0                 STDP-209
      IF (LO(11)) XX(1,I)=XX(1,I)/DSQRT(DABS(1.D0-X4*XX(3,I)))          STDP-210
   26 Y1=Y1+XX(1,I)**2                                                  STDP-211
      Y1=Y1-0.5D0*XX(1,KN)**2                                           STDP-212
      Y2=Y4*XX(1,KN)**2/RR                                              STDP-213
      Y1=Y1*H*.25D0+Y2                                                  STDP-214
      Y2=100.D0*Y2/Y1                                                   STDP-215
      Y1=1.D0/DSQRT(Y1*HS/H)                                            STDP-216
      IS=0                                                              STDP-217
      DO 27 I=4,KN,4                                                    STDP-218
      IS=IS+1                                                           STDP-219
   27 FO(IS)=Y1*XX(1,I)                                                 STDP-220
      WRITE (6,1009) X3,Y2                                              STDP-221
   28 IF (LT(2)) WRITE (6,1010) (IS,FO(IS),IS=1,ISM)                    STDP-222
      RETURN                                                            STDP-223
   29 WRITE (6,1011)                                                    STDP-224
      RETURN                                                            STDP-225
 1000 FORMAT (6F10.5)                                                   STDP-226
 1001 FORMAT (5X,3HN =,I3,5X,3HL =,I3,5X,3HJ =,I3,5X,21HSAXON-WOODS POTESTDP-227
     1NTIAL)                                                            STDP-228
 1002 FORMAT (10X,30HNUMBER OF STEP MULTIPLIED BY 4,10X,I4,18H STEP,AGRESTDP-229
     1EMENT AT,I4,3H TH)                                                STDP-230
 1003 FORMAT (10X,10HTOTAL MASS,F7.1,10X,18HPRODUCT OF CHARGES,F7.1,10X STDP-231
     1  ,14HCOULOMB RADIUS,F10.4/10X,59HSEARCH ON THE CENTRAL POTENTIAL STDP-232
     2STRENGTH     REDUCED RADIUS,F10.4,5X,11HDIFFUSENESS,F10.4/10X,21HLSTDP-233
     3.S COUPLING STRENGTH,F10.4,5X,14HREDUCED RADIUS,F10.4,5X,11HDIFFUSSTDP-234
     4IVITY,F10.4/10X,23H******** BINDING ENERGY,F10.4,11H MEV ******)  STDP-235
 1004 FORMAT (/10X,23H NON-LOCALITY PARAMETER,D15.6/)                   STDP-236
 1005 FORMAT (10X,17H CONVERGENCE STEP)                                 STDP-237
 1006 FORMAT (10X,24HAGREEMENT REACHED FOR I=,I3,5H WITH,I6,7H POINTS)  STDP-238
 1007 FORMAT (2X,I3,5X,12H2*N (+0/1) =,I3,5X,3HV =,D20.10,5X,3HD =,D20.1STDP-239
     10)                                                                STDP-240
 1008 FORMAT (24H INTERPOLATION FOR 2*N =,I4,5X,7HBETWEEN,I4,4H AND,I4) STDP-241
 1009 FORMAT (//18H STRENGTH OBTAINED,D20.10,4H MEV,20X,18HPERCENTAGE OFSTDP-242
     1 TAIL,F10.5/)                                                     STDP-243
 1010 FORMAT (6(I6,D15.6))                                              STDP-244
 1011 FORMAT (25H ***** STOP IN STDP *****)                             STDP-245
      END                                                               STDP-246
