C 11/12/99                                                      DWBA98  FDIS-000
      SUBROUTINE FDIS(W,NW,LX,KN,XC,VR,F,PH,IDMT,NTOT,IE,WF,LX2,NIE,IG) FDIS-001
C CALCULATE THE DISTORTED WAVES.                                        FDIS-002
C INPUTS:   W,NW        WORKING ARRAY.                                  FDIS-003
C           LX          NUMBER OF COULOMB FUNCTIONS NECESSARY.          FDIS-004
C                       (ONE MORE FOR THE CORRECTIONS)                  FDIS-005
C           KN          NUMBER OF INTEGRATION POINTS.                   FDIS-006
C           IDMT        TOTAL DIMENSION OF THE WORKING AREA.            FDIS-007
C           NTOT        DIMENSION OF THE FREE WORKING AREA VR.          FDIS-008
C           LX2         NUMBER OF COULOMB PHASE SHIFTS REQUIRED.        FDIS-009
C           NIE         FIRST FREE ADDRESS IN W.                        FDIS-010
C           IG          1 FOR THE INITIAL STATE, 2 FOR THE FINAL STATE. FDIS-011
C OUTPUTS:  XC          PHASE SHIFTS.                                   FDIS-012
C           VR          POTENTIALS.                                     FDIS-013
C           F           COULOMB FUNCTIONS AND FINAL INTEGRALS.          FDIS-014
C           PH          DISTORTED WAVE FUNCTIONS.                       FDIS-015
C           WF          PHASE SHIFTS AND INTEGRALS FROM 0 TO INFINITY.  FDIS-016
C WORKING AREAS:IE   POWERS OF 10 FOR THE COULOMB FUNCTIONS.            FDIS-017
C DATA IN COMMON /LIMIT/    ( SEE CALC )                                FDIS-018
C           VAL(I,J)    INITIAL STATE FOR J=1, FINAL FOR J=2.           FDIS-019
C                       OPTICAL POTENTIAL FOR I=1,16.                   FDIS-020
C                       MASSES FOR I=17,18.                             FDIS-021
C                       PRODUCT OF CHARGES FOR I=19.                    FDIS-022
C                       ENERGY FOR I=20.                                FDIS-023
C                       NON-LOCALITY PARAMETER FOR I=21.                FDIS-024
C OUTPUTS:  COEF        NORMALISATION FACTOR FOR THE AMPLITUDES.        FDIS-025
C           LX1         MAXIMUM FOR THE COULOMB FUNCTIONS.              FDIS-026
C DATA IN COMMON /NOMBR/    ( SEE CALC )                                FDIS-027
C           H           INTEGRATION STEP.                               FDIS-028
C           LO          LOGICAL CONTROLS.                               FDIS-029
C                          LO(5)=.TRUE.  READ POTENTIAL OF FINAL STATE. FDIS-030
C                          LO(9)=.TRUE.  RELATIVISTIC CORRECTIONS.      FDIS-031
C                          LO(10)=.TRUE. COULOMB CORRECTIONS.           FDIS-032
C                          LO(11)=.TRUE. NON-LOCALITY CORRECTIONS.      FDIS-033
C                          LO(15)=.TRUE. PUNCH PHASE-SHIFTS ON TAPE 7.  FDIS-034
C                          LO(16)=.TRUE. COULOMB INTERACTION.           FDIS-035
C                          LO(22)=.TRUE. EXCHANGE CALC. IN PROGRESS.    FDIS-036
C                          LO(33)=.TRUE. PRINT PHASE-SHIFTS.            FDIS-037
C                          LO(35)=.TRUE. PRINT ELASTIC SCATTERING.      FDIS-038
C                          LO(36)=.TRUE. EXTERNALLY CALCULATED POTENTIALFDIS-039
C                          LO(37)=.TRUE. POTENTIAL COMPUTED FROM THE    FDIS-040
C                                        TWO BODY INTERACTION           FDIS-041
C DATA SAVED IN THE COMMON /GARDE/  IN DOUBLE PRECISION.                FDIS-042
C               ECM     ENERGIES IN THE CENTRE OF MASS.                 FDIS-043
C               SK      WAVE NUMBERS.                                   FDIS-044
C               ETA     COULOMB PARAMETERS.                             FDIS-045
C               AMRED   REDUCED MASSES.                                 FDIS-046
C               SGL     COULOMB PHASE SHIFTS FOR L=0.                   FDIS-047
C SIGNIFICANCE OF THE QUANTITIES IN COMMON /POIN/                       FDIS-048
C   ( COMPUTATION OF THE POTENTIAL FROM THE TWO BODY INTERACTION )      FDIS-049
C    IJMAX:     TWICE THE MAXIMUM VALUE OF TOTAL MOMENTUM IN THE        FDIS-050
C               DESCRIPTION OF THE TARGET.                              FDIS-051
C    NRY:       LOGICAL NUMBER OF THE STORAGE FILE.                     FDIS-052
C    JMY:       NUMBER OF MULTIPOLES TAKEN INTO ACCOUNT IN THE EXCHANGE.FDIS-053
C    LMY:       ANGULAR MOMENTUM OF THE DISTORTED WAVE ABOVE WHICH      FDIS-054
C               EXCHANGE IS NOT TAKEN INTO ACCOUNT.                     FDIS-055
C    KVA:       STORAGE OF KV IN THIS PART OF CALCULATION.              FDIS-056
C    CMY:       MINIMUM EFFECT TO ELASTIC PHASE SHIFTS TO NEGLECT FIRST FDIS-057
C               DERIVATIVE IN THE DIRECT TERMS.                         FDIS-058
C    CCA(2,2):  STORAGE OF TWO BODY COULOMB COEFFICIENTS.               FDIS-059
C LOX(1)=.TRUE.  FOR NO EXCHANGE IN THE COMPUTATION OF THE POTENTIAL    FDIS-060
C                    FROM THE TWO BODY INTERACTION.                     FDIS-061
C LOX(2)=.TRUE.  FOR COULOMB POTENTIAL COMPUTED FROM THE TWO BODY       FDIS-062
C                    INTERACTION.                                       FDIS-063
C LOX(3)=.TRUE.  FOR SPECIAL VALUES OF THE TWO BODY COULOMB POTENTIAL   FDIS-064
C                    FOR THIS PART OF COMPUTATION. STORAGE OF LO(16)    FDIS-065
C                    ( USE OF COULOMB INTERACTION IN THE TRANSITION ).  FDIS-066
C LOX(4)=.TRUE.  TO WRITE ON A FILE THE POTENTIALS COMPUTED FROM THE    FDIS-067
C                    TWO BODY INTERACTION.                              FDIS-068
C LOX(5)=.TRUE.  TO READ POTENTIALS FROM A FILE.                        FDIS-069
C LOX(6)=.TRUE.  READ SPECIAL DATA AS FILE NUMBER AND LIMITATIONS TO    FDIS-070
C                    THE EXCHANGE. AFTER, INDICATION TO NOT COMPUTE     FDIS-071
C                    EXCHANGE.                                          FDIS-072
C LOX(7)=.TRUE.  PRINT PROTON AND NEUTRON DENSITIES.                    FDIS-073
C LOX(8)=.TRUE.  CALCULATION WITH CENTRAL AND SPIN ORBIT POTENTIALS.    FDIS-074
C    ENE:     REDUCED VALUE OF THE ENERGY FOR THE INTEGRATION.          FDIS-075
C    CRPT:    REDUCED COEFFICIENT OF THE POTENTIALS FOR THE INTEGRATION.FDIS-076
C    NVTS:    ADDRESS OF WORKING ARRAY VS.                              FDIS-077
C    NMUS:    ADDRESS OF THE MULTIPOLES.                                FDIS-078
C    NTMS:    ADDRESS OF MACROSCOPIC POTENTIALS.                        FDIS-079
C    NTP:     LENGTH OF THE STORAGE OF THE DESCRIPTION OF THE TARGET.   FDIS-080
C***********************************************************************FDIS-081
      IMPLICIT REAL*8 (A-H,O-Z)                                         FDIS-082
      LOGICAL LO,LOX                                                    FDIS-083
      DIMENSION VR(INM,4),XC(4,1),F(LX,4,3),IE(1),WF(LX2,3),VA(5),DVA(5)FDIS-084
     1,PH(KN,1),W(1),NW(1),FF(6)                                        FDIS-085
      COMMON /LIMIT/ COEF,TMIN,TMAX,TITRE(18),VAL(21,2),NG(8),JMX,MTJ,NJFDIS-086
     1,MPAR,INM,MTETA,NAF,NAMP,NKTF,NCMU,NCH(3),NCZ(3),NCOU,NFA,NFO,NFONFDIS-087
     2,NINT,NFF,NMUL,NPLACE,NQU,NSOM,NT1,NT2,NVT,NFB,JMAX1,LX1,NWF,NMF  FDIS-088
      COMMON /NOMBR/ H,CCO(5),JMAX,KV,KR,KS,NBCONF,NBPROT,J,KY,ILL(3,4),FDIS-089
     1LO(40)                                                            FDIS-090
      COMMON /GARDE/ ECM(2),SK(2),ETA(2),AMRED(2),SGL(2)                FDIS-091
      COMMON /POIN/ CMY,CCA(2,2),ENE,CRPT,IJMAX,NRY,JMY,LMY,KVA,LOX(8),NFDIS-092
     1VTS,NMUS,NTMS                                                     FDIS-093
      WRITE (6,1000) (VAL(I,IG),I=17,19)                                FDIS-094
      IF (LO(11)) WRITE (6,1001) VAL(21,IG)                             FDIS-095
      IF (IG.EQ.2) GO TO 2                                              FDIS-096
      WRITE (6,1002) VAL(20,1)                                          FDIS-097
C CALCULATE CENTER OF MASS ENERGY                                       FDIS-098
      IF (LO(9)) GO TO 1                                                FDIS-099
      ECM(IG)=VAL(20,IG)*VAL(17,IG)/(VAL(17,IG)+VAL(18,IG))             FDIS-100
      GO TO 3                                                           FDIS-101
    1 ECM(IG)=931.5017646D0*(DSQRT((VAL(17,IG)+VAL(18,IG))**2+2.*VAL(17,FDIS-102
     1IG)*VAL(20,IG)/931.5017646D0)-VAL(17,IG)-VAL(18,IG))              FDIS-103
      GO TO 3                                                           FDIS-104
    2 ECM(2)=ECM(1)-VAL(20,2)                                           FDIS-105
      WRITE (6,1003) VAL(20,2)                                          FDIS-106
      IF (ECM(2).LE.0.) GO TO 19                                        FDIS-107
C COMPUTE THE POTENTIALS                                                FDIS-108
    3 ATIERS=VAL(17,IG)**0.3333333333D0                                 FDIS-109
      CALL POTE(ATIERS,VAL(1,IG),INM,VR,W(NMUS),W(NVTS),W(NFO),NW(NQU),NFDIS-110
     1W(NCZ(2)),W(NCH(2)),NW(NKTF),W(NCMU),W(NMF),W(NINT),JMX,IG)       FDIS-111
C CALCULATE THE WAVE NUMBER AND THE COULOMB PARAMETER.                  FDIS-112
      IF (LO(9)) GO TO 4                                                FDIS-113
      AMRED(IG)=VAL(17,IG)*VAL(18,IG)/(VAL(17,IG)+VAL(18,IG))           FDIS-114
      WSK2=0.047844673D0*ECM(IG)*AMRED(IG)                              FDIS-115
      GO TO 5                                                           FDIS-116
    4 AMT=VAL(17,IG)+(ECM(1)-ECM(IG))/931.5017646D0                     FDIS-117
      IF (LO(10)) AMT=VAL(17,IG)                                        FDIS-118
      AMR=ECM(1)/931.5017646D0+VAL(17,1)+VAL(18,1)                      FDIS-119
      AMRED(IG)=(AMR**4-(VAL(18,IG)**2-AMT**2)**2)/(4.D0*AMR**3)        FDIS-120
      WSK2=0.005980584125D0*ECM(IG)*(ECM(IG)/931.5017646D0+2.D0*VAL(18,IFDIS-121
     1G)+2.D0*AMT)*(ECM(IG)/931.5017646D0+2.D0*VAL(18,IG))*(ECM(IG)/931.FDIS-122
     25017646D0+2.D0*AMT)/AMR**2                                        FDIS-123
    5 SK(IG)=DSQRT(DABS(WSK2))                                          FDIS-124
      ENE=H**2*SK(IG)**2                                                FDIS-125
      CRPT=-H**2*0.047844673D0*AMRED(IG)                                FDIS-126
      ETA(IG)=0.0344475893D0*AMRED(IG)*VAL(19,IG)/SK(IG)                FDIS-127
      A1=AMRED(IG)*(VAL(17,IG)+VAL(18,IG))/(VAL(17,IG)*VAL(18,IG))      FDIS-128
      WRITE (6,1004) ECM(IG),SK(IG),ETA(IG),A1                          FDIS-129
      IF (IG.EQ.2) COEF=0.047844673D0*DSQRT(AMRED(1)*AMRED(2)/(4.D0*SK(2FDIS-130
     1)*SK(1)**3))                                                      FDIS-131
      IF (.NOT.LO(37)) GO TO 6                                          FDIS-132
      IF (LOX(1).AND.(ILL(3,1).NE.0)) GO TO 6                           FDIS-133
      LO(22)=.TRUE.                                                     FDIS-134
      NP=NPLACE+16*INM*INM                                              FDIS-135
      IF (2*NP.GT.IDMT) CALL MEMO(IDMT,2*NP,NQ,3,LO)                    FDIS-136
      IF (LO(19)) GO TO 21                                              FDIS-137
C COMPUTATION OF COULOMB FUNCTIONS                                      FDIS-138
    6 LMX=LX-4                                                          FDIS-139
      RAU=SK(IG)*H*INM                                                  FDIS-140
      CALL FCOU(LX-1,ETA(IG),RAU,F(1,1,IG),F(1,2,IG),F(1,3,IG),F(1,4,IG)FDIS-141
     1,IE,SGL(IG))                                                      FDIS-142
      API=(MOD(IG,2)-.5D0)*3.141592653589793D0                          FDIS-143
      DRHO=SK(IG)*H                                                     FDIS-144
      B1=DRHO*DRHO/48.D0                                                FDIS-145
      C1=RAU-1.5D0*DRHO                                                 FDIS-146
      IF (IG.EQ.1) LX1=LX                                               FDIS-147
      SGLL=SGL(IG)                                                      FDIS-148
      DO 7 I=1,5                                                        FDIS-149
      C1=C1+0.5D0*DRHO                                                  FDIS-150
      VA(I)=B1*(2.D0*ETA(IG)/C1-1.D0)                                   FDIS-151
    7 DVA(I)=2.D0*B1/(C1*C1)                                            FDIS-152
      JJ=0                                                              FDIS-153
      AJ=0.D0                                                           FDIS-154
      IF (LO(33)) WRITE (6,1005)                                        FDIS-155
      IF (LO(15)) WRITE (7,1006) IG,LMX                                 FDIS-156
      IF (LO(15)) WRITE (7,1007) VAL(18,IG),VAL(17,IG),SK(IG),ETA(IG),AMFDIS-157
     1RED(IG),SGL(IG)                                                   FDIS-158
C LOOP ON THE PARTIAL WAVES                                             FDIS-159
      DO 11 M=1,LMX                                                     FDIS-160
      DO 10 K=1,2                                                       FDIS-161
      LI=M+K-1                                                          FDIS-162
      JL=2*M+K-2                                                        FDIS-163
      IF (LI.LE.JJ) GO TO 10                                            FDIS-164
C CALCULATE COULOMB FUNCTIONS AT TWO SEPARATE POINTS FROM THEIR VALUES  FDIS-165
C AND THEIR DERIVATIVES IN THE MIDDLE USING FOUR NUMEROV INTEGRATION    FDIS-166
C STEPS AND A SEVEN POINTS DIFFERENTIATION FORMULA.                     FDIS-167
      DO 8 I=1,5                                                        FDIS-168
    8 VA(I)=VA(I)+DVA(I)*AJ                                             FDIS-169
      JJ=JJ+1                                                           FDIS-170
      IF (IE(JJ).EQ.0) GO TO 9                                          FDIS-171
      LX1=MIN0(LX1,JJ)                                                  FDIS-172
      F(JJ,1,IG)=F(JJ,1,IG)*1.D-15                                      FDIS-173
      F(JJ,2,IG)=F(JJ,2,IG)*1.D-15                                      FDIS-174
      F(JJ,3,IG)=F(JJ,3,IG)*1.D15                                       FDIS-175
      F(JJ,4,IG)=F(JJ,4,IG)*1.D15                                       FDIS-176
    9 A1=(1.D0-VA(2))/(2.D0+10.D0*VA(2))                                FDIS-177
      B1=(1.D0-VA(4))/(2.D0+10.D0*VA(4))                                FDIS-178
      A2=A1*(1.D0-VA(1))/(1.D0-4.D0*VA(1))                              FDIS-179
      B2=B1*(1.D0-VA(5))/(1.D0-4.D0*VA(5))                              FDIS-180
      C1=(2.D0+10.D0*VA(3))-(1.D0-VA(3))*(A1+B1)                        FDIS-181
      A1=(16.D0-144.D0*VA(2))/(2.D0+10.D0*VA(2))                        FDIS-182
      B1=(16.D0-144.D0*VA(4))/(2.D0+10.D0*VA(4))                        FDIS-183
      C2=(7.D0+A1*(1.D0-VA(1)))/(1.D0-4.D0*VA(1))                       FDIS-184
      D2=(7.D0+B1*(1.D0-VA(5)))/(1.D0-4.D0*VA(5))                       FDIS-185
      D1=(B1-A1)*(1.D0-VA(3))                                           FDIS-186
      A1=A2*D2+B2*C2                                                    FDIS-187
      X11=(C1*D2+D1*B2)/A1                                              FDIS-188
      X12=30.D0*DRHO*B2/A1                                              FDIS-189
      X21=(C2*C1-A2*D1)/A1                                              FDIS-190
      X22=-30.D0*DRHO*A2/A1                                             FDIS-191
      FF(1)=X21*F(JJ,1,IG)-X22*F(JJ,2,IG)                               FDIS-192
      FF(2)=X21*F(JJ,3,IG)-X22*F(JJ,4,IG)                               FDIS-193
      FF(3)=X11*F(JJ,1,IG)-X12*F(JJ,2,IG)                               FDIS-194
      FF(4)=X11*F(JJ,3,IG)-X12*F(JJ,4,IG)                               FDIS-195
      FF(5)=DCOS(SGLL)                                                  FDIS-196
      FF(6)=DSIN(SGLL)                                                  FDIS-197
      AJ=JJ                                                             FDIS-198
      SGLL=SGLL+DATAN2(ETA(IG),AJ)+API                                  FDIS-199
      IF (LX.NE.LX1) WRITE (6,1008) LX,LX1                              FDIS-200
   10 CALL INTE(M,K,INM,VR,FF,W(NMUS),W(NVTS),PH(1,2*JL-1),XC(1,JL),W(NFFDIS-201
     1O),W(NFB),NFA,NW(NQU),NW(NCZ(2)),W(NCH(2)),NW(NKTF),W(NCMU),W(NMF)FDIS-202
     2,W(NINT),W(NPLACE),VA,SK(IG))                                     FDIS-203
      IF (LO(15)) WRITE (7,1007) XC(1,JL-1),XC(2,JL-1),XC(1,JL),XC(2,JL)FDIS-204
      IF (.NOT.LO(33)) GO TO 11                                         FDIS-205
      S1=125.6637D0*M*(XC(2,JL-1)-XC(1,JL-1)**2-XC(2,JL-1)**2)/SK(IG)**2FDIS-206
      S2=125.6637D0*M*(XC(2,JL)-XC(1,JL)**2-XC(2,JL)**2)/SK(IG)**2      FDIS-207
      WRITE (6,1009) M,XC(1,JL-1),XC(2,JL-1),S1,XC(1,JL),XC(2,JL),S2    FDIS-208
   11 CONTINUE                                                          FDIS-209
      IF (.NOT.LO(37)) GO TO 13                                         FDIS-210
C RESTORE QUANTITIES WHICH WERE TEMPORARILY CHANGED FOR THE COMPUTATION FDIS-211
C OF POTENTIALS FROM THE TWO BODY INTERACTION                           FDIS-212
      KV=KVA                                                            FDIS-213
      LO(16)=LOX(3)                                                     FDIS-214
      LOX(5)=LOX(4)                                                     FDIS-215
      DO 12 I=1,2                                                       FDIS-216
   12 CCO(I)=CCA(I,1)                                                   FDIS-217
   13 IF (.NOT.LO(11)) GO TO 16                                         FDIS-218
C NON-LOCALITY CORRECTIONS                                              FDIS-219
      IF (LO(36).OR.LO(37)) GO TO 20                                    FDIS-220
      U=0.047844673D0*AMRED(IG)*VAL(2,IG)*VAL(21,IG)**2                 FDIS-221
      JT=2*JL                                                           FDIS-222
      DO 15 IS=1,INM                                                    FDIS-223
      CC=1.D0/DSQRT(1.D0+U/(1.D0+DEXP((IS*H-ATIERS*VAL(3,IG))/VAL(4,IG))FDIS-224
     1))                                                                FDIS-225
      DO 14 JJ=1,JT                                                     FDIS-226
   14 PH(IS,JJ)=PH(IS,JJ)*CC                                            FDIS-227
   15 CONTINUE                                                          FDIS-228
   16 IF (.NOT.LO(10).OR.IG.EQ.1) GO TO 18                              FDIS-229
C CALCULATION OF THE COULOMB INTEGRALS TO BE SAVED.                     FDIS-230
      RS=H*INM*DSQRT(SK(1)*SK(2))                                       FDIS-231
      CALL CORI(ETA(1),ETA(2),RS,WF(1,3),SGL(1),SGL(2),F,F(1,1,2),W(NIE FDIS-232
     1),LX,LX2,NTOT-2*NIE,LX1,F(1,1,3),IDMT,LO)                         FDIS-233
      WF(1,1)=SGL(1)                                                    FDIS-234
      WF(1,2)=SGL(2)                                                    FDIS-235
      DO 17 I=2,LX2                                                     FDIS-236
      A1=I-1                                                            FDIS-237
      WF(I,1)=WF(I-1,1)+DATAN2(ETA(1),A1)+1.5707963268D0                FDIS-238
   17 WF(I,2)=WF(I-1,2)+DATAN2(ETA(2),A1)-1.5707963268D0                FDIS-239
   18 IF (LO(35)) CALL SCEL(XC,IG,W(NIE),W(NIE+5*JMAX),MTETA,IDMT-2*NIE-FDIS-240
     112*JMAX,JMAX,IDMT,LO)                                             FDIS-241
      IF (IG.EQ.1) LO(5)=.TRUE.                                         FDIS-242
      RETURN                                                            FDIS-243
   19 WRITE (6,1010)                                                    FDIS-244
      LO(5)=.TRUE.                                                      FDIS-245
      RETURN                                                            FDIS-246
   20 WRITE (6,1011)                                                    FDIS-247
      GO TO 16                                                          FDIS-248
   21 WRITE (6,1012)                                                    FDIS-249
      RETURN                                                            FDIS-250
 1000 FORMAT (19H MASS OF THE TARGET,13X,D15.6/32H MASS OF THE INCIDENT FDIS-251
     1PARTICLE   ,D15.6/15H CHARGE PRODUCT,12X,D20.6)                   FDIS-252
 1001 FORMAT (/90X,26H NON-LOCALITY PARAMETER   ,D15.6/)                FDIS-253
 1002 FORMAT (16H INCIDENT ENERGY,11X,D20.6/)                           FDIS-254
 1003 FORMAT (/9H **** Q =,D20.6,4H ***/)                               FDIS-255
 1004 FORMAT (/6H ECM =,D15.6,5X,3HK =,D15.6,5X,5HETA =,D15.6,5X,3HG =,DFDIS-256
     115.6/)                                                            FDIS-257
 1005 FORMAT (6H J+1/2,2X,12HL=J-1/2 REAL,6X,9HIMAGINARY,6X,10HABSORPTIOFDIS-258
     1N,11X,12HL=J+1/2 REAL,6X,9HIMAGINARY,6X,10HABSORPTION)            FDIS-259
 1006 FORMAT (4X,1H1/2I5)                                               FDIS-260
 1007 FORMAT (4D18.10)                                                  FDIS-261
 1008 FORMAT (41H NUMBER OF COULOMB INTEGRALS REDUCED FROM,I6,3H TO,I6) FDIS-262
 1009 FORMAT (2X,I4,3D16.7,6X,3D16.7)                                   FDIS-263
 1010 FORMAT (//16H ENERGY NEGATIVE)                                    FDIS-264
 1011 FORMAT (55H NO NON-LOCALITY CORRECTION WITHOUT STANDARD POTENTIALSFDIS-265
     1)                                                                 FDIS-266
 1012 FORMAT (25H ***** STOP IN FDIS *****)                             FDIS-267
      END                                                               FDIS-268
