C 03/04/98                                                      DWBA98  INTE-000
      SUBROUTINE INTE(JI,KZ,INM,VR,FF,AM,VS,PH,CR,FO,FAC,NFA,NQUA,NCHE,AINTE-001
     1X,KTF,CMU,CVF,VX,XA,VA,SK)                                        INTE-002
C CALCULATE THE DISTORTED WAVES.                                        INTE-003
C INPUTS:  JI        VALUE OF J+1/2.                                    INTE-004
C          KZ        1 FOR J=L+1/2, 2 FOR J=L-1/2.                      INTE-005
C          INM       NUMBER OF INTEGRATION POINTS.                      INTE-006
C          VR(KN,I)  CENTRAL POTENTIAL  REAL AND IMAGINARY FOR I=1,2.   INTE-007
C                    SPIN ORBIT POTENTIALS FOR I=3,4.                   INTE-008
C          FF        VALUES OF THE COULOMB FUNCTIONS - REGULAR          INTE-009
C                    AND IRREGULAR AT R+H AND R-H.                      INTE-010
C                    COSINE AND SINE OF THE COULOMB PHASE SHIFTS.       INTE-011
C          VS(KN,I)  TRANSITION FORM-FACTOR FOR 0+.                     INTE-012
C                    VALUES FOR I=1,2,3,4,11,12,15,16,27,28,39 AND 40.  INTE-013
C          FO        BOUND STATE WAVE FUNCTIONS.                        INTE-014
C          FAC,NFA   LOGARITHMS OF FACTORIALS AND LENGTH OF THE TABLE.  INTE-015
C          NQUA      QUANTUM NUMBERS OF THE BOUND STATES.               INTE-016
C          NCHE,AX   DESCRIPTION OF THE TARGET.                         INTE-017
C          KTF,CMU,CVF   DESCRIPTION OF THE INTERACTION.                INTE-018
C          VX        RADIAL DEPENDENCES OF THE INTERACTION.             INTE-019
C          VA        POTENTIAL AT POINTS R+H AND R-H.                   INTE-020
C          SK        WAVE NUMBER.                                       INTE-021
C OUTPUT:  PH(KN,2)  REAL AND IMAGINARY PARTS OF THE WAVE FUNCTIONS.    INTE-022
C          CR(2)     PHASE SHIFTS.                                      INTE-023
C WORKING SPACE: AM  FOR THE MULTIPOLES.                                INTE-024
C                VS  IN ITS UNUSED ARRAYS.                              INTE-025
C                XA  NON LOCAL INTERACTION AND LINEAR SYSTEM:           INTE-026
C                     NON DERIVATIVE TERMS IN XA(*,*,1) AND XA(*,*,2).  INTE-027
C                     1ST DERIVATIVE TERMS IN XA(*,*,3) AND XA(*,*,4).  INTE-028
C                     2ND DERIVATIVE TERMS IN XA(*,*,5) AND XA(*,*,6).  INTE-029
C                       LINEAR SYSTEM IN XA(*,*,7) AND XA(*,*,8).       INTE-030
C FOR COMMON /NOMBR/   SEE CALC                                         INTE-031
C FOR COMMON /POIN/   SEE FDIS.                                         INTE-032
C FOR COMMON /GABJ/   SEE MULT.                                         INTE-033
C***********************************************************************INTE-034
      IMPLICIT REAL*8 (A-H,O-Z)                                         INTE-035
      LOGICAL LO,LOO,LOX                                                INTE-036
      DIMENSION VS(INM,40),AM(INM,18,1),FO(INM,1),PH(INM,2),KTF(7,7,1),VINTE-037
     1X(INM,1),AX(2,1),NCHE(2,1),NQUA(3,1),CMU(1),CVF(7,6,1),FAC(1),XA(IINTE-038
     2NM,INM,8),FF(6),VA(5),CR(2),VR(INM,4)                             INTE-039
      COMMON /NOMBR/ H,CCO(5),JMAX,KV,KR,KS,NBCONF,NBPROT,J,KY,ILL(3,4),INTE-040
     1LO(40)                                                            INTE-041
      COMMON /GABJ/ AA,AB,AJ,BJ,CJ,DJ,XG(11),JX                         INTE-042
      COMMON /POIN/ CMY,CCA(2,2),ENE,CRPT,IJMAX,NRY,JMY,LMY,KVA,LOX(8),NINTE-043
     1VTS,NMUS,NTMS                                                     INTE-044
      YL=JI+KZ-1                                                        INTE-045
      XL=YL*(YL-1.D0)                                                   INTE-046
      AC=2*JI*(2*MOD(KZ,2)-1)                                           INTE-047
      IF (.NOT.LO(37).OR.(ILL(3,1).EQ.0)) GO TO 4                       INTE-048
      IF (JI*KZ.NE.1) GO TO 2                                           INTE-049
C AT FIRST CALL WITH MICROSCOPIC POTENTIAL, INVERT 1+DIAGONAL SECOND    INTE-050
C DERIVATIVE IN PLACE (39,40) AND MULTIPLY FIRST DERIVATIVES BY THE     INTE-051
C RESULT IN (27,28).                                                    INTE-052
      DO 1 N=1,INM                                                      INTE-053
      A=1.D0+VS(N,39)*CRPT                                              INTE-054
      B=VS(N,40)*CRPT                                                   INTE-055
      C=A**2+B**2                                                       INTE-056
      VS(N,39)=A/C                                                      INTE-057
      VS(N,40)=-B/C                                                     INTE-058
      A=VS(N,27)*VS(N,39)-VS(N,28)*VS(N,40)                             INTE-059
      VS(N,28)=CRPT*(VS(N,27)*VS(N,40)+VS(N,28)*VS(N,39))               INTE-060
    1 VS(N,27)=CRPT*A                                                   INTE-061
C WITH MICROSCOPIC POTENTIAL, COMPUTE TOTAL POTENTIAL MULTIPLIED BY     INTE-062
C INVERSE OF SECOND DERIVATIVES WHICH ARE IN (39,40).                   INTE-063
    2 DO 3 N=1,INM                                                      INTE-064
      A=-(VS(N,3)+VS(N,11)*AC+VS(N,15)*AC**2)*CRPT+XL/DFLOAT(N)**2-ENE  INTE-065
      B=-(VS(N,4)+VS(N,12)*AC+VS(N,16)*AC**2)*CRPT                      INTE-066
      PH(N,1)=A*VS(N,39)-B*VS(N,40)                                     INTE-067
    3 PH(N,2)=A*VS(N,40)+B*VS(N,39)                                     INTE-068
      GO TO 6                                                           INTE-069
C ONLY CENTRAL AND SPIN ORBIT POTENTIALS. COMPUTES TOTAL POTENTIAL.     INTE-070
    4 FJ=.5D0*AC-1.D0                                                   INTE-071
      DO 5 N=1,INM                                                      INTE-072
      PH(N,1)=(VR(N,1)+VR(N,3)*FJ)*CRPT+XL/DFLOAT(N)**2-ENE             INTE-073
    5 PH(N,2)=(VR(N,2)+VR(N,4)*FJ)*CRPT                                 INTE-074
      IF (.NOT.LO(37)) GO TO 8                                          INTE-075
C MICROSCOPIC POTENTIAL: KEEP TOTAL POTENTIAL IN (37,38).               INTE-076
    6 DO 7 N=1,INM                                                      INTE-077
      VS(N,37)=PH(N,1)                                                  INTE-078
    7 VS(N,38)=PH(N,2)                                                  INTE-079
C COMPUTE  2 + H**2*V / ( 1 - H**2*V /12).                              INTE-080
    8 DO 9 N=1,INM                                                      INTE-081
      B=(12.D0-PH(N,1))**2+PH(N,2)**2                                   INTE-082
      PH(N,1)=12.D0*(PH(N,1)*(12.D0-PH(N,1))-PH(N,2)**2)/B              INTE-083
    9 PH(N,2)=144.D0*PH(N,2)/B                                          INTE-084
      XER=1.D-20                                                        INTE-085
      X1=XER                                                            INTE-086
      X2=0.D0                                                           INTE-087
      Y1=0.D0                                                           INTE-088
      Y2=0.D0                                                           INTE-089
C INTEGRATION LOOP.                                                     INTE-090
      DO 11 N=1,INM                                                     INTE-091
      X3=X2                                                             INTE-092
      Y3=Y2                                                             INTE-093
      X2=X1                                                             INTE-094
      Y2=Y1                                                             INTE-095
      X1=(2.D0+PH(N,1))*X2-PH(N,2)*Y2-X3                                INTE-096
      Y1=(2.D0+PH(N,1))*Y2+PH(N,2)*X2-Y3                                INTE-097
      PH(N,1)=(10.D0*X2+X1+X3)/12.D0                                    INTE-098
      PH(N,2)=(10.D0*Y2+Y1+Y3)/12.D0                                    INTE-099
      IF (XER*(DABS(X3)+DABS(Y3)).LT.1.D0) GO TO 11                     INTE-100
      X1=(X1*XER)*XER                                                   INTE-101
      X2=(X2*XER)*XER                                                   INTE-102
      X3=(X3*XER)*XER                                                   INTE-103
      Y1=(Y1*XER)*XER                                                   INTE-104
      Y2=(Y2*XER)*XER                                                   INTE-105
      Y3=(Y3*XER)*XER                                                   INTE-106
      DO 10 I=1,N                                                       INTE-107
      PH(I,1)=(PH(I,1)*XER)*XER                                         INTE-108
   10 PH(I,2)=(PH(I,2)*XER)*XER                                         INTE-109
   11 CONTINUE                                                          INTE-110
C MATCHING.                                                             INTE-111
      IK=1                                                              INTE-112
   12 X2=X3*FF(1)-X1*FF(3)                                              INTE-113
      Y2=Y3*FF(1)-Y1*FF(3)                                              INTE-114
      X1=X1*FF(4)-X3*FF(2)                                              INTE-115
      Y1=Y1*FF(4)-Y3*FF(2)                                              INTE-116
      X1=X1+Y2                                                          INTE-117
      Y1=Y1-X2                                                          INTE-118
      X3=Y1/X1                                                          INTE-119
      X1=1.D0/(X1+Y1*X3)                                                INTE-120
      Y1=-X3*X1                                                         INTE-121
      CR(1)=X2*X1-Y2*Y1                                                 INTE-122
      CR(2)=X2*Y1+Y2*X1                                                 INTE-123
C NORMALISATION OF THE SOLUTION.                                        INTE-124
      X2=FF(1)*FF(4)-FF(2)*FF(3)                                        INTE-125
      A=(X1*FF(5)-Y1*FF(6))*X2                                          INTE-126
      B=(X1*FF(6)+Y1*FF(5))*X2                                          INTE-127
      IF (IK.EQ.2) GO TO 49                                             INTE-128
      DO 13 N=1,INM                                                     INTE-129
      C=PH(N,1)*A-PH(N,2)*B                                             INTE-130
      PH(N,2)=PH(N,1)*B+PH(N,2)*A                                       INTE-131
   13 PH(N,1)=C                                                         INTE-132
C END EXCEPT FOR MICROSCOPIC CALCULATION.                               INTE-133
      IF (.NOT.LO(37)) RETURN                                           INTE-134
      IF ((ILL(3,1).EQ.0).OR.(.NOT.LOX(6))) GO TO 15                    INTE-135
C WITHOUT EXCHANGE, ESTIMATION OF THE CONTRIBUTION OF FIRST DERIVATIVES.INTE-136
      CALL DERI(PH,VS(1,5),INM)                                         INTE-137
      CALL DERI(PH(1,2),VS(1,6),INM)                                    INTE-138
      AR=0.D0                                                           INTE-139
      AI=0.D0                                                           INTE-140
      DO 14 N=1,INM                                                     INTE-141
      BR=VS(N,5)*VS(N,27)-VS(N,6)*VS(N,28)                              INTE-142
      BI=VS(N,6)*VS(N,27)+VS(N,5)*VS(N,28)                              INTE-143
      AR=AR+BR*PH(N,1)-BI*PH(N,2)                                       INTE-144
   14 AI=AI+BI*PH(N,1)+BR*PH(N,2)                                       INTE-145
      LOX(8)=DABS(AR)+DABS(AI).LT.CMY*H*SK                              INTE-146
   15 IF (LOX(6).AND.LOX(8)) RETURN                                     INTE-147
      IF (LOX(5)) GO TO 24                                              INTE-148
C INITIALISATION OF THE MATRIX XA FOR THE EXCHANGE.                     INTE-149
      DO 18 L=1,INM                                                     INTE-150
      DO 17 K=1,INM                                                     INTE-151
      DO 16 N=1,7                                                       INTE-152
   16 XA(K,L,N)=0.D0                                                    INTE-153
   17 CONTINUE                                                          INTE-154
   18 CONTINUE                                                          INTE-155
      IF (KS.EQ.0.OR.LOX(6)) GO TO 25                                   INTE-156
      IF (JI+KZ-2.GT.LMY) GO TO 23                                      INTE-157
      IJT=2*JI-1                                                        INTE-158
C LOOP ON THE MULTIPOLES FOR THE EXCHANGE.                              INTE-159
      JM1=MAX0((IJT-IJMAX)/2,0)+1                                       INTE-160
      JM2=MIN0((IJT+IJMAX)/2+1,JMY)                                     INTE-161
      IF (JM1.GT.JM2) GO TO 23                                          INTE-162
      NTOT=0                                                            INTE-163
      JY=0                                                              INTE-164
      DO 22 JM=JM1,JM2                                                  INTE-165
      JX=JM-1                                                           INTE-166
      CALL MULT(AM,INM,CMU,JY-1)                                        INTE-167
      JY=JM                                                             INTE-168
C LOOP ON THE CONFIGURATIONS.                                           INTE-169
      DO 21 K=1,NBCONF                                                  INTE-170
      DO 20 M=1,2                                                       INTE-171
      NPAR=NCHE(M,K)                                                    INTE-172
      NTRO=NCHE(3-M,K)                                                  INTE-173
      NP=1                                                              INTE-174
      IF (NPAR.GT.NBPROT) NP=3                                          INTE-175
      IJP=2*NQUA(2,NPAR)+NQUA(3,NPAR)                                   INTE-176
      IF ((IABS(IJP-IJT).GT.2*JX).OR.((IJP+IJT).LT.2*JX)) GO TO 20      INTE-177
      NTOT=NTOT+1                                                       INTE-178
      G=-AX(M,K)*DFLOAT(2*JX+1)*DCGS(2*JX,IJT,IJP,FAC,NFA)**2/DFLOAT(IJPINTE-179
     1+1)/DFLOAT(IJT+1)                                                 INTE-180
      IF (G.EQ.0.) GO TO 20                                             INTE-181
      LOO=MOD(JI+NQUA(2,NPAR)+JX,2).NE.0                                INTE-182
      KX=3-KZ                                                           INTE-183
      IF (LOO) KX=KZ                                                    INTE-184
C CALCULATION OF THE CHANNEL GEOMETRY.                                  INTE-185
      AP=0.5D0*DFLOAT(IJP+1)                                            INTE-186
      AT=0.5D0*DFLOAT(IJT+1)                                            INTE-187
      AK=1-MOD(IJT+IJP+2*JX,4)                                          INTE-188
      AJT=1.D0                                                          INTE-189
      IF (LOO) AJT=-1.D0                                                INTE-190
      AB=AJT*(AK*AP-AT)                                                 INTE-191
      AA=AJT*(AK*AP+AT)                                                 INTE-192
      CALL GEOM                                                         INTE-193
      LO(31)=KX.EQ.1                                                    INTE-194
      DO 19 I=1,INM                                                     INTE-195
      VS(I,5)=FO(I,NTRO)                                                INTE-196
   19 VS(I,6)=FO(I,NPAR)                                                INTE-197
      CALL DERI(VS(1,6),VS(1,7),INM)                                    INTE-198
      CALL DER2(VS(1,6),VS(1,8),INM)                                    INTE-199
      NTOT=NTOT+1                                                       INTE-200
      IF (KX.EQ.1) CALL PTIP(KTF,CMU,CVF,VX,AM,VS,VS(1,5),XA,INM,NP,G)  INTE-201
      IF (KX.EQ.2) CALL PTII(KTF,CMU,CVF,VX,AM,VS,VS(1,5),XA,INM,NP,G)  INTE-202
   20 CONTINUE                                                          INTE-203
   21 CONTINUE                                                          INTE-204
   22 CONTINUE                                                          INTE-205
C TEST ON THE PRESENCE OF EXCHANGE, INPUT OR OUTPUT.                    INTE-206
      IF (NTOT.EQ.0) GO TO 23                                           INTE-207
      IF (LOX(4)) WRITE (NRY) (((XA(I,L,N),I=1,INM),L=1,INM),N=1,6)     INTE-208
      GO TO 25                                                          INTE-209
   23 LOX(6)=.TRUE.                                                     INTE-210
      GO TO 25                                                          INTE-211
   24 READ (NRY,END=25) (((XA(N,L,K),N=1,INM),L=1,INM),K=1,6)           INTE-212
   25 IF (LOX(6).AND.LOX(8)) RETURN                                     INTE-213
C NORMALISATION OF EXCHANGE POTENTIAL.                                  INTE-214
      DO 31 I=1,INM                                                     INTE-215
      DO 27 N=1,INM                                                     INTE-216
      DO 26 L=1,6                                                       INTE-217
   26 XA(N,I,L)=-XA(N,I,L)*CRPT                                         INTE-218
   27 CONTINUE                                                          INTE-219
      IF (ILL(3,1).EQ.0) GO TO 30                                       INTE-220
C MULTIPLICATION BY THE INVERSE OF DIAGONAL SECOND DERIVATIVES.         INTE-221
      DO 29 N=1,INM                                                     INTE-222
      DO 28 K=1,3                                                       INTE-223
      C=VS(I,39)*XA(I,N,2*K-1)-VS(I,40)*XA(I,N,2*K)                     INTE-224
      XA(I,N,2*K)=VS(I,39)*XA(I,N,2*K)+VS(I,40)*XA(I,N,2*K-1)           INTE-225
   28 XA(I,N,2*K-1)=C                                                   INTE-226
   29 CONTINUE                                                          INTE-227
C ADDITION OF DIRECT POTENTIALS.                                        INTE-228
   30 XA(I,I,1)=XA(I,I,1)+VS(I,37)                                      INTE-229
      XA(I,I,2)=XA(I,I,2)+VS(I,38)                                      INTE-230
      XA(I,I,3)=XA(I,I,3)+VS(I,27)                                      INTE-231
      XA(I,I,4)=XA(I,I,4)+VS(I,28)                                      INTE-232
   31 XA(I,I,5)=XA(I,I,5)-1.D0                                          INTE-233
      IN1=INM-1                                                         INTE-234
C CONSTRUCTION OF THE LINEAR SYSTEM OF EQUATIONS WITH THE LOWEST        INTE-235
C APPROXIMATION FOR FIRST AND SECOND DERIVATIVES. THE DIAGONAL          INTE-236
C SECOND DERIVATIVES ARE SKIPPED.                                       INTE-237
      DO 34 I=1,INM                                                     INTE-238
      DO 32 N=1,INM                                                     INTE-239
      XA(I,N,7)=XA(I,N,1)                                               INTE-240
   32 XA(I,N,8)=XA(I,N,2)                                               INTE-241
      XA(I,1,7)=XA(I,1,7)+YL*XA(I,1,3)                                  INTE-242
      XA(I,1,8)=XA(I,1,8)+YL*XA(I,1,4)                                  INTE-243
      IF (I.NE.1) XA(I,1,7)=XA(I,1,7)+XL*XA(I,1,5)                      INTE-244
      IF (I.NE.1) XA(I,1,8)=XA(I,1,8)+XL*XA(I,1,6)                      INTE-245
      DO 33 N=2,IN1                                                     INTE-246
      XA(I,N-1,7)=XA(I,N-1,7)-.5D0*XA(I,N,3)                            INTE-247
      XA(I,N-1,8)=XA(I,N-1,8)-.5D0*XA(I,N,4)                            INTE-248
      XA(I,N+1,7)=XA(I,N+1,7)+.5D0*XA(I,N,3)                            INTE-249
      XA(I,N+1,8)=XA(I,N+1,8)+.5D0*XA(I,N,4)                            INTE-250
      IF (I.EQ.N) GO TO 33                                              INTE-251
      XA(I,N,7)=XA(I,N,7)-2.D0*XA(I,N,5)                                INTE-252
      XA(I,N,8)=XA(I,N,8)-2.D0*XA(I,N,6)                                INTE-253
      XA(I,N-1,7)=XA(I,N-1,7)+XA(I,N,5)                                 INTE-254
      XA(I,N-1,8)=XA(I,N-1,8)+XA(I,N,6)                                 INTE-255
      XA(I,N+1,7)=XA(I,N+1,7)+XA(I,N,5)                                 INTE-256
      XA(I,N+1,8)=XA(I,N+1,8)+XA(I,N,6)                                 INTE-257
   33 CONTINUE                                                          INTE-258
   34 CONTINUE                                                          INTE-259
C CONSTRUCTION OF THE SYSTEM OF EQUATIONS TO SOLVE THE DIFFERENTIAL     INTE-260
C EQUATION DEFINED BY THE DIAGONAL SECOND DERIVATIVES.                  INTE-261
      DO 37 N=1,INM                                                     INTE-262
      X1=0.D0                                                           INTE-263
      Y1=0.D0                                                           INTE-264
      DO 35 I=2,INM                                                     INTE-265
      X2=X1                                                             INTE-266
      Y2=Y1                                                             INTE-267
      X1=XA(N,I-1,7)                                                    INTE-268
      Y1=XA(N,I-1,8)                                                    INTE-269
      XA(N,I-1,7)=(X2+10.D0*X1+XA(N,I,7))/12.D0                         INTE-270
   35 XA(N,I-1,8)=(Y2+10.D0*Y1+XA(N,I,8))/12.D0                         INTE-271
      XA(N,INM,7)=(X1+10.D0*XA(N,INM,7))/12.D0                          INTE-272
      XA(N,INM,8)=(Y1+10.D0*XA(N,INM,8))/12.D0                          INTE-273
      XA(N,N,7)=XA(N,N,7)-2.D0*XA(N,N,5)                                INTE-274
      XA(N,N,8)=XA(N,N,8)-2.D0*XA(N,N,6)                                INTE-275
      IF (N.EQ.1) GO TO 36                                              INTE-276
      XA(N,N-1,7)=XA(N,N-1,7)+XA(N,N,5)                                 INTE-277
      XA(N,N-1,8)=XA(N,N-1,8)+XA(N,N,6)                                 INTE-278
   36 IF (N.EQ.INM) GO TO 37                                            INTE-279
      XA(N,N+1,7)=XA(N,N+1,7)+XA(N,N,5)                                 INTE-280
      XA(N,N+1,8)=XA(N,N+1,8)+XA(N,N,6)                                 INTE-281
   37 CONTINUE                                                          INTE-282
C INVERSION OF THE LINEAR EQUATIONS.                                    INTE-283
      DO 41 I=1,INM                                                     INTE-284
      QQ=XA(I,I,7)**2+XA(I,I,8)**2                                      INTE-285
      QR=XA(I,I,7)/QQ                                                   INTE-286
      QI=-XA(I,I,8)/QQ                                                  INTE-287
      XA(I,I,7)=1.D0                                                    INTE-288
      XA(I,I,8)=0.D0                                                    INTE-289
      DO 38 L=1,INM                                                     INTE-290
      QQ=XA(I,L,7)*QR-XA(I,L,8)*QI                                      INTE-291
      XA(I,L,8)=XA(I,L,7)*QI+XA(I,L,8)*QR                               INTE-292
   38 XA(I,L,7)=QQ                                                      INTE-293
      DO 40 L1=1,INM                                                    INTE-294
      IF (L1.EQ.I) GO TO 40                                             INTE-295
      QR=XA(L1,I,7)                                                     INTE-296
      QI=XA(L1,I,8)                                                     INTE-297
      XA(L1,I,7)=0.D0                                                   INTE-298
      XA(L1,I,8)=0.D0                                                   INTE-299
      DO 39 L=1,INM                                                     INTE-300
      QQ=XA(I,L,7)*QR-XA(I,L,8)*QI                                      INTE-301
      XA(L1,L,8)=XA(L1,L,8)-XA(I,L,7)*QI-XA(I,L,8)*QR                   INTE-302
   39 XA(L1,L,7)=XA(L1,L,7)-QQ                                          INTE-303
   40 CONTINUE                                                          INTE-304
   41 CONTINUE                                                          INTE-305
C THE SOLUTION NORMALISED TO 1. AT THE POINT INM+1 IS THE LAST ROW.     INTE-306
      DO 42 N=1,INM                                                     INTE-307
      VS(N,5)=XA(N,INM,7)                                               INTE-308
   42 VS(N,7)=XA(N,INM,8)                                               INTE-309
C LOOP OF CORRECTION FOR THE SOLUTION.                                  INTE-310
      DO 47 K=1,4                                                       INTE-311
C SINGLE AND DOUBLE DERIVATION OF THE SOLUTION, ADDING A POINT WITH     INTE-312
C VALUE 1. TO COMPUTE SECOND DERIVATIVES.                               INTE-313
      VS(1,6)=1.D0                                                      INTE-314
      VS(1,8)=0.D0                                                      INTE-315
      CALL DER2(VS(1,5),VS(1,13),INM+1)                                 INTE-316
      CALL DER2(VS(1,7),VS(1,14),INM+1)                                 INTE-317
      CALL DERI(VS(1,5),VS(1,6),INM)                                    INTE-318
      CALL DERI(VS(1,7),VS(1,8),INM)                                    INTE-319
C CALCULATION OF THE ERRORS IN (9,10).                                  INTE-320
      DO 44 N=1,INM                                                     INTE-321
      VS(N,9)=0.D0                                                      INTE-322
      VS(N,10)=0.D0                                                     INTE-323
      DO 43 I=1,INM                                                     INTE-324
      VS(N,9)=VS(N,9)-XA(N,I,1)*VS(I,5)+XA(N,I,2)*VS(I,7)-XA(N,I,5)*VS(IINTE-325
     1,13)+XA(N,I,6)*VS(I,14)-XA(N,I,3)*VS(I,6)+XA(N,I,4)*VS(I,8)       INTE-326
   43 VS(N,10)=VS(N,10)-XA(N,I,2)*VS(I,5)-XA(N,I,1)*VS(I,7)-XA(N,I,6)*VSINTE-327
     1(I,13)-XA(N,I,5)*VS(I,14)-XA(N,I,4)*VS(I,6)-XA(N,I,3)*VS(I,8)     INTE-328
   44 CONTINUE                                                          INTE-329
      AR=0.D0                                                           INTE-330
C CORRECTION OF THE SOLUTION DUE TO THE ERROR USING THE INVERTED MATRIX.INTE-331
      DO 46 N=1,INM                                                     INTE-332
      VS(N,21)=0.D0                                                     INTE-333
      VS(N,22)=0.D0                                                     INTE-334
      DO 45 I=1,INM                                                     INTE-335
      VS(N,21)=VS(N,21)+VS(I,9)*XA(N,I,7)-VS(I,10)*XA(N,I,8)            INTE-336
   45 VS(N,22)=VS(N,22)+VS(I,9)*XA(N,I,8)+VS(I,10)*XA(N,I,7)            INTE-337
      VS(N,5)=VS(N,5)+VS(N,21)                                          INTE-338
      VS(N,7)=VS(N,7)+VS(N,22)                                          INTE-339
   46 AR=AR+VS(N,21)**2+VS(N,22)**2                                     INTE-340
C STOP THE LOOP ON CORRECTIONS IF THEIR SUM IS SMALL.                   INTE-341
      IF (AR.LT.CMY) GO TO 48                                           INTE-342
   47 CONTINUE                                                          INTE-343
C PREPARATION OF THE COMPUTATION OF PHASE SHIFTS AND NORMALISATION.     INTE-344
   48 IK=2                                                              INTE-345
      X1=1.D0-4.D0*VA(5)                                                INTE-346
      Y1=0.D0                                                           INTE-347
      X3=VS(INM-1,5)*(1.D0-4.D0*VA(1))                                  INTE-348
      Y3=VS(INM-1,7)*(1.D0-4.D0*VA(1))                                  INTE-349
      GO TO 12                                                          INTE-350
   49 AR=0.D0                                                           INTE-351
C NORMALISATION AND COMPARISON TO SOLUTION OF SIMPLEST POTENTIAL.       INTE-352
      DO 50 N=1,INM                                                     INTE-353
      C=VS(N,5)*A-VS(N,7)*B                                             INTE-354
      D=VS(N,5)*B+VS(N,7)*A                                             INTE-355
      AR=AR+(PH(N,1)-C)**2+(PH(N,2)-D)**2                               INTE-356
      PH(N,1)=C                                                         INTE-357
   50 PH(N,2)=D                                                         INTE-358
      IF (AR.GT.CMY) RETURN                                             INTE-359
      LOX(6)=.TRUE.                                                     INTE-360
      LOX(8)=.TRUE.                                                     INTE-361
      RETURN                                                            INTE-362
      END                                                               INTE-363
