C 03/04/98                                                      DWBA98  CORI-000
      SUBROUTINE CORI(EI,EF,RS,T,SSI,SSF,FGI,FGF,Z,LM1,LM2,LM3,LM,W,IDMTCORI-001
     1,LO)                                                              CORI-002
C    CALCULATES THE INTEGRALS FROM RS TO INFINITY OF THE PRODUCT OF THE CORI-003
C REGULAR OR IRREGULAR COULOMB FUNCTIONS OF THE SAME L DIVIDED  BY R**2 CORI-004
C FOR L=0 TO LM-1. THE UNITS ARE SUCH THAT KI*KF=1.                     CORI-005
C ENTREES:   EI,EF   COULOMB PARAMETERS.                                CORI-006
C            RS      STARTING LIMIT OF THE INTEGRAL.                    CORI-007
C            SSI,SSF COULOMB PHASE SHIFTS FOR L=0.                      CORI-008
C            FGI,FGF REGULAR AND IRREGULAR COULOMB FUNCTIONS.           CORI-009
C            Z       WORKING AREA FOR THE CALCULATION OF F AND G.       CORI-010
C                            USED ALSO IN THE SUBPROGRAMME  CORH.       CORI-011
C            LM1     MAXIMUM NUMBER OF INTEGRALS FROM RS TO INFINITY.   CORI-012
C            LM2     NUMBER OF INTEGRALS FROM 0 TO INFINITY FOR CORH.   CORI-013
C            LM3     DIMENSION OF THE WORK AREA IN SINGLE PRECISION     CORI-014
C            LM      EFFECTIVE NUMBER OF INTEGRALS FROM RS TO INFINITY. CORI-015
C            IDMT    TOTAL DIMENSION OF THE WORKING AREA.               CORI-016
C            LO      LOGICAL CONTROLS.                                  CORI-017
C OUTPUTS:   W       INTEGRALS FROM RS TO INFINITY.                     CORI-018
C            T       INTEGRALS FROM 0 TO INFINITY FOR THE PRODUCTS OF   CORI-019
C                           REGULAR FUNCTIONS GIVEN BY CORH.            CORI-020
C***********************************************************************CORI-021
      IMPLICIT REAL*8 (A-H,O-Z)                                         CORI-022
      LOGICAL LO(40)                                                    CORI-023
      DIMENSION W(LM1,4),X(4),U(4),X5(4),X1(4),X2(4),X3(4),X4(4),FGI(LM1CORI-024
     1,3),FGF(LM1,3),Z(2,4,1),C(4,4),T(4),Y(4,4),AR(4),AI(4),YY(2),BI(2)CORI-025
     2,IE(2),ABSC(20),P(20)                                             CORI-026
      DATA ABSC( 1),P( 1) / 0.88114514472040D-03, 0.22606385492666D-02/ CORI-027
      DATA ABSC( 2),P( 2) / 0.46368806502715D-02, 0.52491422655764D-02/ CORI-028
      DATA ABSC( 3),P( 3) / 0.11370025008113D-01, 0.82105291909539D-02/ CORI-029
      DATA ABSC( 4),P( 4) / 0.21041590393104D-01, 0.11122924597084D-01/ CORI-030
      DATA ABSC( 5),P( 5) / 0.33593595860662D-01, 0.13968503490012D-01/ CORI-031
      DATA ABSC( 6),P( 6) / 0.48950596515563D-01, 0.16730097641274D-01/ CORI-032
      DATA ABSC( 7),P( 7) / 0.67020248393870D-01, 0.19391083987236D-01/ CORI-033
      DATA ABSC( 8),P( 8) / 0.87693884583344D-01, 0.21935454092836D-01/ CORI-034
      DATA ABSC( 9),P( 9) / 0.11084717428674D+00, 0.24347903817536D-01/ CORI-035
      DATA ABSC(10),P(10) / 0.13634087240504D+00, 0.26613923491968D-01/ CORI-036
      DATA ABSC(11),P(11) / 0.16402165769291D+00, 0.28719884549696D-01/ CORI-037
      DATA ABSC(12),P(12) / 0.19372305516601D+00, 0.30653121246465D-01/ CORI-038
      DATA ABSC(13),P(13) / 0.22526643745244D+00, 0.32402006728300D-01/ CORI-039
      DATA ABSC(14),P(14) / 0.25846209915691D+00, 0.33956022907617D-01/ CORI-040
      DATA ABSC(15),P(15) / 0.29311039781420D+00, 0.35305823695643D-01/ CORI-041
      DATA ABSC(16),P(16) / 0.32900295458712D+00, 0.36443291197902D-01/ CORI-042
      DATA ABSC(17),P(17) / 0.36592390749637D+00, 0.37361584528984D-01/ CORI-043
      DATA ABSC(18),P(18) / 0.40365120964931D+00, 0.38055180950313D-01/ CORI-044
      DATA ABSC(19),P(19) / 0.44195796466237D+00, 0.38519909082124D-01/ CORI-045
      DATA ABSC(20),P(20) / 0.48061379124697D+00, 0.38752973989212D-01/ CORI-046
C CALCULATE THE INTEGRALS FROM 0 TO INFINITY AND LOG(GAMMA(0.,EI-EF))   CORI-047
      CALL CORH(EI,EF,LM2,SSI,SSF,ZR,ZI,T,Z,LM3,IDMT,LO)                CORI-048
      FS=DSQRT(EI/EF)                                                   CORI-049
      RM=DMAX1((5.D0*EI+22.5D0)*FS,(5.D0*EF+22.5D0)/FS,.18D0*EI*EF)/3.D0CORI-050
      IF (RM.LT.RS) RM=RS                                               CORI-051
C CALCULATES INTEGRALS FROM RM TO INFINITY FOR L=0,1 WITH RAWITSCHER'S  CORI-052
C METHOD. (COMP. PHYSICS COMM., VOL.11,183,1976)                        CORI-053
C RESULTS ARE IN C(I,J,K,L): I=1 FOR F(EI) , I=2 FOR G(EI)              CORI-054
C                            J=1 FOR F(EF) , J=2 FOR G(EF)              CORI-055
C                            K=1 FOR LI=0 ,  K=2 FOR LI=1               CORI-056
C                            L=1 FOR LF=0 ,  L=2 FOR LF=1               CORI-057
      R=RM/FS                                                           CORI-058
      S=RM*FS                                                           CORI-059
      T1=R-EI*DLOG(2.D0*R)+SSI                                          CORI-060
      T3=S-EF*DLOG(2.D0*S)+SSF                                          CORI-061
C FIRST TERM OF THE ASYMPTOTIC EXPANSION OF H(+/-) FOR L=0,1            CORI-062
      Z(1,1,1)=DCOS(T1)                                                 CORI-063
      Z(2,1,1)=DSIN(T1)                                                 CORI-064
      Z(1,3,1)=DCOS(T3)                                                 CORI-065
      Z(2,3,1)=DSIN(T3)                                                 CORI-066
      T2=T1+DATAN(EI)                                                   CORI-067
      T4=T3+DATAN(EF)                                                   CORI-068
      Z(1,2,1)=DSIN(T2)                                                 CORI-069
      Z(2,2,1)=-DCOS(T2)                                                CORI-070
      Z(1,4,1)=DSIN(T4)                                                 CORI-071
      Z(2,4,1)=-DCOS(T4)                                                CORI-072
      YY(1)=-R-S                                                        CORI-073
      BI(1)=EI+EF                                                       CORI-074
      YY(2)=S-R                                                         CORI-075
      BI(2)=EI-EF                                                       CORI-076
      CI=0.D0                                                           CORI-077
      T5=0.D0                                                           CORI-078
      IF (YY(2).EQ.0.D0) GO TO 1                                        CORI-079
      T5=DSIGN(ZI,YY(2))+YY(2)+BI(2)*DLOG(DABS(YY(2)))                  CORI-080
      CI=DEXP(-DSIGN(1.5707963267948966D0,YY(2))*BI(2)+ZR)              CORI-081
    1 WI=DSIN(T5)*CI                                                    CORI-082
      WR=CI*DCOS(T5)                                                    CORI-083
      DO 2 J=1,16                                                       CORI-084
    2 Y(J,1)=0.D0                                                       CORI-085
      FI=EI**2                                                          CORI-086
      FF=EF**2                                                          CORI-087
      N=MIN0(IDINT(R+DSQRT(R**2-FI))+2,IDINT(S+DSQRT(S**2-FF))+2)       CORI-088
      XN=-1.D0                                                          CORI-089
      AM=0.D0                                                           CORI-090
C LOOP FOR THE ASYMPTOTIC EXPANSION                                     CORI-091
      DO 19 I=1,N                                                       CORI-092
      IF (16*I.GT.LM3) CALL MEMO(IDMT,IDMT+16*I-LM3,LM3,3,LO)           CORI-093
      IF (LO(19)) GO TO 40                                              CORI-094
      XN=XN+1.D0                                                        CORI-095
      IF (I.EQ.1) GO TO 4                                               CORI-096
      XM=1.D0-.5D0/XN                                                   CORI-097
      AR(1)=EI*XM/R                                                     CORI-098
      AR(2)=AR(1)                                                       CORI-099
      AR(3)=EF*XM/S                                                     CORI-100
      AR(4)=AR(3)                                                       CORI-101
      AI(1)=(FI-XN*(XN-1.D0))/(2.D0*XN*R)                               CORI-102
      AI(2)=(FI-(XN+1.D0)*(XN-2.D0))/(2.D0*XN*R)                        CORI-103
      AI(3)=(FF-XN*(XN-1.D0))/(2.D0*XN*S)                               CORI-104
      AI(4)=(FF-(XN+1.D0)*(XN-2.D0))/(2.D0*XN*S)                        CORI-105
C NEW TERM IN THE ASYMPTOTIC EXPANSION                                  CORI-106
      DO 3 J=1,4                                                        CORI-107
      Z(1,J,I)=Z(1,J,I-1)*AR(J)-Z(2,J,I-1)*AI(J)                        CORI-108
    3 Z(2,J,I)=Z(1,J,I-1)*AI(J)+Z(2,J,I-1)*AR(J)                        CORI-109
    4 DO 5 J=1,16                                                       CORI-110
    5 C(J,1)=0.D0                                                       CORI-111
C PRODUCTS OF THE ASYMPTOTIC EXPANSIONS                                 CORI-112
      DO 8 J=1,I                                                        CORI-113
      M=I+1-J                                                           CORI-114
      DO 7 K=1,2                                                        CORI-115
      DO 6 L=1,2                                                        CORI-116
      C(2*K-1,L)=C(2*K-1,L)+(Z(1,K,J)*Z(1,L+2,M)-Z(2,K,J)*Z(2,L+2,M))   CORI-117
      C(2*K,L)=C(2*K,L)+(Z(1,K,J)*Z(2,L+2,M)+Z(2,K,J)*Z(1,L+2,M))       CORI-118
      C(2*K-1,L+2)=C(2*K-1,L+2)+Z(1,K,J)*Z(1,L+2,M)+Z(2,K,J)*Z(2,L+2,M) CORI-119
    6 C(2*K,L+2)=C(2*K,L+2)-(Z(1,K,J)*Z(2,L+2,M)-Z(2,K,J)*Z(1,L+2,M))   CORI-120
    7 CONTINUE                                                          CORI-121
    8 CONTINUE                                                          CORI-122
      BR=XN+2.D0                                                        CORI-123
      BM=0.D0                                                           CORI-124
C INTEGRATION FROM RS TO INFINITY                                       CORI-125
      DO 18 M=1,2                                                       CORI-126
      IF (DABS(YY(M)).LE.2.D0.AND.M.EQ.2) GO TO 12                      CORI-127
C PADE APPROXIMANT FOR THE FUNCTION OMEGA                               CORI-128
C INSTEAD OF THE FORMULA (44), CALCULATES I*K*R*OMEGA IN TERMS OF I*K*R CORI-129
      CZ=BR**2+(BI(M)+YY(M))**2                                         CORI-130
      SR=BR/CZ                                                          CORI-131
      SI=-(BI(M)+YY(M))/CZ                                              CORI-132
      AX3=-SI*YY(M)                                                     CORI-133
      AX4=SR*YY(M)                                                      CORI-134
      AY3=SR                                                            CORI-135
      AY4=SI+1.D0/YY(M)                                                 CORI-136
      AN=1.D0                                                           CORI-137
C STEED'S ALGORITHM                                                     CORI-138
      DO 9 J=1,1000                                                     CORI-139
      AX2=AX4+YY(M)/AN                                                  CORI-140
      CZ=(AX3**2+AX2**2)*AN                                             CORI-141
      AX1=AX3/CZ                                                        CORI-142
      AX2=-AX2/CZ                                                       CORI-143
      AY1=-(AX2*YY(M)+1.D0)*AY3-AX1*YY(M)*AY4                           CORI-144
      AY2=AX1*YY(M)*AY3-AY4*(AX2*YY(M)+1.D0)                            CORI-145
      AX3=1.D0+AX1*(BR+AN)-AX2*BI(M)                                    CORI-146
      AX4=AX1*BI(M)+(BR+AN)*AX2                                         CORI-147
      CZ=AX3**2+AX4**2                                                  CORI-148
      AX3=AX3/CZ                                                        CORI-149
      AX4=-AX4/CZ                                                       CORI-150
      AY3=(AX3-1.D0)*AY1-AX4*AY2                                        CORI-151
      AY4=(AX3-1.D0)*AY2+AX4*AY1                                        CORI-152
      AN=AN+1.D0                                                        CORI-153
      IF (DABS(AY1)+DABS(AY2)+DABS(AY3)+DABS(AY4).LT.1.D-12*(DABS(SI)+DACORI-154
     1BS(SR))) GO TO 10                                                 CORI-155
      SR=SR+AY3+AY1                                                     CORI-156
    9 SI=SI+AY4+AY2                                                     CORI-157
   10 RR=0.D0                                                           CORI-158
      RI=0.D0                                                           CORI-159
      J=J+1                                                             CORI-160
C DIRECT CALCULATION OF THE PADE APPROXIMANT FOR GREATER PRECISION      CORI-161
      DO 11 K=1,J                                                       CORI-162
      AX1=1.D0+AN*RR                                                    CORI-163
      AX2=AN*RI                                                         CORI-164
      CZ=AX1**2+AX2**2                                                  CORI-165
      AN=AN-1.D0                                                        CORI-166
      AX3=((BR+AN)*AX1+BI(M)*AX2)/CZ                                    CORI-167
      AX4=YY(M)+(AX1*BI(M)-AX2*(BR+AN))/CZ                              CORI-168
      CZ=AX3**2+AX4**2                                                  CORI-169
      RR=AX3/CZ                                                         CORI-170
   11 RI=-AX4/CZ                                                        CORI-171
      GO TO 16                                                          CORI-172
C TAYLOR EXPANSION FOR THE CONFLUENT HYPERGEOMETRIC FUNCTION            CORI-173
   12 SR=1.D0                                                           CORI-174
      SI=0.D0                                                           CORI-175
      IF (YY(M).EQ.0.D0) GO TO 15                                       CORI-176
      XR=1.D0                                                           CORI-177
      XI=0.D0                                                           CORI-178
      DO 13 J=1,1000                                                    CORI-179
      AN=J+1                                                            CORI-180
      CZ=YY(M)/((AN-BR)**2+BI(M)**2)                                    CORI-181
      CR=-(XR*BI(M)+XI*(AN-BR))*CZ                                      CORI-182
      XI=(XR*(AN-BR)-XI*BI(M))*CZ                                       CORI-183
      XR=CR                                                             CORI-184
      SR=SR+XR                                                          CORI-185
      SI=SI+XI                                                          CORI-186
      IF (DABS(XR)+DABS(XI).LT.1.D-12*(DABS(SR)+DABS(SI))) GO TO 14     CORI-187
   13 CONTINUE                                                          CORI-188
C CALCULATION OF THETA. FORMULA (47)                                    CORI-189
   14 WR=WR*YY(M)                                                       CORI-190
      WI=WI*YY(M)                                                       CORI-191
   15 CZ=-1.D0/((BR-1.D0)**2+BI(M)**2)                                  CORI-192
      CR=(BI(M)*WR-WI*(BR-1.D0))*CZ                                     CORI-193
      WI=(BI(M)*WI+(BR-1.D0)*WR)*CZ                                     CORI-194
      WR=CR                                                             CORI-195
      RI=(SR*BI(M)-SI*(BR-1.D0))*CZ+WI                                  CORI-196
      RR=-(BI(M)*SI+(BR-1.D0)*SR)*CZ+WR                                 CORI-197
C STORAGE OF INTEGRALS WITHIN A FACTOR RR                               CORI-198
   16 DO 17 J=1,4                                                       CORI-199
      SR=C(2*J-1,2*M-1)*RR-C(2*J,2*M-1)*RI                              CORI-200
      SI=C(2*J-1,2*M-1)*RI+C(2*J,2*M-1)*RR                              CORI-201
      BM=DMAX1(BM,SR**2+SI**2)                                          CORI-202
      Y(2*J-1,2*M-1)=Y(2*J-1,2*M-1)+SR                                  CORI-203
      Y(2*J,2*M-1)=Y(2*J,2*M-1)+SI                                      CORI-204
   17 AM=DMAX1(AM,Y(2*J-1,2*M-1)**2+Y(2*J,2*M-1)**2)                    CORI-205
   18 CONTINUE                                                          CORI-206
      IF (BM.LT.AM*1.D-30) GO TO 20                                     CORI-207
   19 CONTINUE                                                          CORI-208
   20 RR=2.D0*RM                                                        CORI-209
C TRANSFORMATION OF H(+/-) TO F AND G                                   CORI-210
      DO 21 I=1,4                                                       CORI-211
      C(1,I)=(Y(2*I-1,3)-Y(2*I-1,1))/RR                                 CORI-212
      C(4,I)=(Y(2*I-1,3)+Y(2*I-1,1))/RR                                 CORI-213
      C(3,I)=(Y(2*I,1)+Y(2*I,3))/RR                                     CORI-214
   21 C(2,I)=(Y(2*I,1)-Y(2*I,3))/RR                                     CORI-215
      IF (RM.EQ.RS) GO TO 28                                            CORI-216
C IF RM IS NOT EQUAL TO RS, 40 GAUSSIAN INTEGRATION POINTS FROM RS TO   CORI-217
C RM. EACH GAUSSIAN STEP IS FOR ONE VARIATION OF R LESS THAN  20.       CORI-218
      INTE=1+IDINT(DABS(RM-RS)*.05D0)                                   CORI-219
      SI=INTE                                                           CORI-220
      SI=(RM-RS)/SI                                                     CORI-221
      RF=RM                                                             CORI-222
      DO 27 IT=1,INTE                                                   CORI-223
      RI=RF-SI                                                          CORI-224
      DO 26 II=1,40                                                     CORI-225
      I=MIN0(II,41-II)                                                  CORI-226
      SR=ABSC(I)                                                        CORI-227
      IF (I.NE.II) SR=1.D0-SR                                           CORI-228
      RR=RI+SI*SR                                                       CORI-229
      CALL FCOU(1,EI,RR/FS,Y,Y(1,3),Y(3,1),Y(3,3),IE,YY)                CORI-230
      CALL FCOU(1,EF,RR*FS,Y(1,2),Y(1,4),Y(3,2),Y(3,4),IE,YY)           CORI-231
      DO 25 LI=1,2                                                      CORI-232
      DO 24 LF=1,2                                                      CORI-233
      DO 23 J=1,2                                                       CORI-234
      DO 22 L=1,2                                                       CORI-235
   22 C(2*L+J-2,2*LF+LI-2)=C(2*L+J-2,2*LF+LI-2)+P(I)*Y(2*J+LI-2,1)*Y(2*LCORI-236
     1+LF-2,2)/RR**2*SI                                                 CORI-237
   23 CONTINUE                                                          CORI-238
   24 CONTINUE                                                          CORI-239
   25 CONTINUE                                                          CORI-240
   26 CONTINUE                                                          CORI-241
   27 RF=RI                                                             CORI-242
C RECURSION RELATION FOR  (0,2;L) :                                     CORI-243
C    ((2*L+1)/(2*L+3))*(L+2)**2*|L+1+I*EI|*|L+1+I*EF|*(0,2;L) -         CORI-244
C  (EI*EF*((L+1)**2+(L+2)**2)+(L+1)**2*(L+2)**2*(EI/EF+EF/EI))*(0,2;L+1)CORI-245
C  + ((2*L+5)/(2*L+3))*(L+1)**2*|L+2+I*EI|*|L+2+I*EF|*(0,2:L+2) =       CORI-246
C    2*EI*(L+1)*|L+2+I*EI|*( (1,2;L+1) + XX*F(L,EI)*F(L+1,EF) )         CORI-247
C    - 2*EF*(L+2)*|L+1+I*EI|*( (1,2;L) + XX*F(L-1,EI)*F(L,EF) )         CORI-248
C    WHERE XX = L*(L+1)/(2*RS**2*DSQRT(EI*EF))                          CORI-249
C                                                                       CORI-250
C RECURSION RELATION FOR  (1,2;L) :                                     CORI-251
C  2*EI*EF*|L+I*EI|*|L+1+I*EF|*(1,2;L-1) - (4*EI**2*EF**2+(L+1)*(2*L+3)*CORI-252
C    EF**2+(L+1)*(2*L+1)*EI**2)*(1,2;L) + 2*EI*EF*|L+1+I*EI|*|L+2+I*EF|*CORI-253
C    (1,2;L+1) = DSQRT(EI*EF)*( EI*(2*L+1)*|L+I*EF|*F(L,EI)*F(L,EF) -   CORI-254
C    EF*(2*L+3)*|L+I*EI|*F(L+1,EI)*F(L+1,EF) )/RS**2.                   CORI-255
C                                                                       CORI-256
C DOWNWARDS RECURSION FOR F*F                                           CORI-257
C U,V,Z,Y ARE RESPECTIVELY F(EI),F(EF),(1,2;L) AND (0,2;L)              CORI-258
   28 Z2=0.D0                                                           CORI-259
      Z3=0.D0                                                           CORI-260
      Y2=0.D0                                                           CORI-261
      Y3=0.D0                                                           CORI-262
      U2=0.D0                                                           CORI-263
      V2=0.D0                                                           CORI-264
      U3=1.D-20                                                         CORI-265
      V3=1.D-20                                                         CORI-266
      S=RS*DSQRT(EI*EF)                                                 CORI-267
      S2=RS*S                                                           CORI-268
      LN=MAX0(LM,IDINT(RS))+50                                          CORI-269
      C2=DSQRT((LN-1)**2+FI)                                            CORI-270
      D1=DSQRT(LN**2+FF)                                                CORI-271
      D2=DSQRT((LN-1)**2+FF)                                            CORI-272
      DO 32 K=3,LN                                                      CORI-273
      I=LN+1-K                                                          CORI-274
      A=I                                                               CORI-275
      C1=C2                                                             CORI-276
      D0=D1                                                             CORI-277
      D1=D2                                                             CORI-278
      C2=DSQRT(A**2+FI)                                                 CORI-279
      D2=DSQRT(A**2+FF)                                                 CORI-280
C DOWNWARDS RECURSION FOR  F(EI) AND F(EF)                              CORI-281
      U1=U2                                                             CORI-282
      U2=U3                                                             CORI-283
      V1=V2                                                             CORI-284
      V2=V3                                                             CORI-285
      U3=((2.D0*A+1.D0)*EI*(1.D0+(A+1.D0)*A/S)*U2-A*C1*U1)/((A+1.D0)*C2)CORI-286
      V3=((2.D0*A+1.D0)*EF*(1.D0+(A+1.D0)*A/S)*V2-A*D1*V1)/((A+1.D0)*D2)CORI-287
C DOWNWARDS RECURSION FOR (1,2;L)                                       CORI-288
      Z1=Z2                                                             CORI-289
      Z2=Z3                                                             CORI-290
      Z3=((2.D0*EI*EF+(A+1.D0)*((A+.5D0)*EI/EF+(A+1.5D0)*EF/EI))*Z2-C1*DCORI-291
     10*Z1+(C1*EF*(A+1.5D0)*U1*V1-EI*D1*(A+.5D0)*U2*V2)/S2)/(C2*D1)     CORI-292
C DOWNWARDS RECURSION FOR (0,2;L)                                       CORI-293
      XX=A*(A+1.D0)/(2*S2)                                              CORI-294
      Y1=Y2                                                             CORI-295
      Y2=Y3                                                             CORI-296
      Y3=((EI*EF*(A**2+(A+1.D0)**2)+A**2*(A+1.D0)**2*(EI/EF+EF/EI))*Y2-(CORI-297
     12.D0*A+3.D0)*A**2*C1*D1*Y1/(2.D0*A+1.D0)-2.D0*EF*(A+1.D0)*C2*(Z3+XCORI-298
     2X*U3*V2)+2.D0*EI*A*D1*(Z2+XX*U2*V1))*(2.D0*A+1.D0)/((2.D0*A-1.D0)*CORI-299
     3(A+1.D0)**2*C2*D2)                                                CORI-300
      IF (I.LE.LM) W(I,1)=Y3                                            CORI-301
      IF (DABS(U3).LT.1.D15) GO TO 29                                   CORI-302
      U3=U3*1.D-30                                                      CORI-303
      U2=U2*1.D-30                                                      CORI-304
      GO TO 30                                                          CORI-305
   29 IF (DABS(V3).LT.1.D15) GO TO 32                                   CORI-306
      V2=V2*1.D-30                                                      CORI-307
      V3=V3*1.D-30                                                      CORI-308
   30 Z3=Z3*1.D-30                                                      CORI-309
      Z2=Z2*1.D-30                                                      CORI-310
      Y3=Y3*1.D-30                                                      CORI-311
      Y2=Y2*1.D-30                                                      CORI-312
      IF (I.GT.LM) GO TO 32                                             CORI-313
      DO 31 J=I,LM                                                      CORI-314
   31 W(J,1)=W(J,1)*1.D-30                                              CORI-315
   32 CONTINUE                                                          CORI-316
C THE VALUES OBTAINED FOR THE INTEGRALS FROM RS TO 0 ARE NOT NORMALISED.CORI-317
C NORMALISATION AND TRANSFORMATION TO INTEGRALS FROM RS TO INFINITY.    CORI-318
      A1=FGI(1,1)*FGF(1,1)/(U3*V3)                                      CORI-319
      DO 33 J=1,LM                                                      CORI-320
   33 W(J,1)=A1*W(J,1)+T(J)                                             CORI-321
      WRITE (6,1000) C(1,1),W(1,1),C(1,4),W(2,1)                        CORI-322
C UPWARD RECURSION FOR THE OTHER INTEGRALS:  STARTING VALUES            CORI-323
      X2(2)=-FGI(1,3)*FGF(2,1)/S2                                       CORI-324
      X2(3)=-FGI(1,1)*FGF(2,3)/S2                                       CORI-325
      X2(4)=-FGI(1,3)*FGF(2,3)/S2                                       CORI-326
      X4(2)=-FGI(2,3)*FGF(2,1)/S2                                       CORI-327
      X4(3)=-FGI(2,1)*FGF(2,3)/S2                                       CORI-328
      X4(4)=-FGI(2,3)*FGF(2,3)/S2                                       CORI-329
      C2=DSQRT(1.D0+FI)                                                 CORI-330
      D2=DSQRT(1.D0+FF)                                                 CORI-331
      D3=DSQRT(4.D0+FF)                                                 CORI-332
      A1=1.5D0*EF*C2/(EI*D3)                                            CORI-333
      A2=-.5D0*D2/D3                                                    CORI-334
      A3=-1.5D0*EF/D3                                                   CORI-335
      DO 34 J=2,4                                                       CORI-336
      W(1,J)=C(J,1)                                                     CORI-337
      W(2,J)=C(J,4)                                                     CORI-338
      X(J)=C(J,3)                                                       CORI-339
   34 X5(J)=A1*X(J)+A2*C(J,2)+A3*X4(J)                                  CORI-340
      DO 39 I=3,LM                                                      CORI-341
      C1=C2                                                             CORI-342
      D1=D2                                                             CORI-343
      D2=D3                                                             CORI-344
      A=I-1                                                             CORI-345
      C2=DSQRT(A**2+FI)                                                 CORI-346
      D3=DSQRT((A+1.D0)**2+FF)                                          CORI-347
C RECURSION FOR (0,2;L)                                                 CORI-348
      A1=(2.D0*A-3.D0)*A**2*C1*D1/(2.D0*A-1.D0)                         CORI-349
      A2=-(EI*EF*((A-1.D0)**2+A**2)+(A-1.D0)**2*A**2*(EI/EF+EF/EI))     CORI-350
      A3=(2.D0*A+1.D0)*(A-1.D0)**2*C2*D2/(2.D0*A-1.D0)                  CORI-351
      A4=2*EF*A*C1                                                      CORI-352
      A5=-2*EI*(A-1.D0)*D2                                              CORI-353
      XX=-.5D0*A*(A-1.D0)                                               CORI-354
      DO 35 J=2,4                                                       CORI-355
   35 X1(J)=X2(J)                                                       CORI-356
      X2(2)=-FGI(I-1,3)*FGF(I,1)/S2                                     CORI-357
      X2(3)=-FGI(I-1,1)*FGF(I,3)/S2                                     CORI-358
      X2(4)=-FGI(I-1,3)*FGF(I,3)/S2                                     CORI-359
      DO 36 J=2,4                                                       CORI-360
   36 W(I,J)=-(A1*W(I-2,J)+A2*W(I-1,J)+A4*(X(J)+XX*X1(J))+A5*(X5(J)+XX*XCORI-361
     12(J)))/A3                                                         CORI-362
C RECURSION FOR (1,2;L)                                                 CORI-363
      B1=C1*D2                                                          CORI-364
      B2=-2.D0*EI*EF-A*((A-.5D0)*EI/EF+(A+.5D0)*EF/EI)                  CORI-365
      B3=C2*D3                                                          CORI-366
      B4=-EI*(A-.5D0)*D2                                                CORI-367
      B5=EF*(A+.5D0)*C2                                                 CORI-368
      DO 37 J=2,4                                                       CORI-369
   37 X3(J)=X4(J)                                                       CORI-370
      X4(2)=-FGI(I,3)*FGF(I,1)/S2                                       CORI-371
      X4(3)=-FGI(I,1)*FGF(I,3)/S2                                       CORI-372
      X4(4)=-FGI(I,3)*FGF(I,3)/S2                                       CORI-373
      DO 38 J=2,4                                                       CORI-374
      U(J)=X(J)                                                         CORI-375
      X(J)=X5(J)                                                        CORI-376
   38 X5(J)=-(B1*U(J)+B2*X(J)+B4*X3(J)+B5*X4(J))/B3                     CORI-377
   39 CONTINUE                                                          CORI-378
      RETURN                                                            CORI-379
   40 WRITE (6,1001)                                                    CORI-380
      STOP                                                              CORI-381
 1000 FORMAT (87H INTEGRALS WITH THE REGULAR FUNCTIONS:     (L+1)       CORI-382
     1DIRECT      DESCENDING RECURSION/46X,1H1,2D20.10/46X,1H2,2D20.10) CORI-383
 1001 FORMAT (25H ***** STOP IN CORI *****)                             CORI-384
      END                                                               CORI-385
