C 30/11/98                                                      DWBA98  SCEL-000
      SUBROUTINE SCEL(XC,IG,AF,TGS,NTGS,NTOT,JMAX,IDMT,LO)              SCEL-001
C CALCULATE THE ELASTIC CROSS SECTIONS AND POLARISATIONS.               SCEL-002
C INPUT:         XC:      PHASE-SHIFTS.                                 SCEL-003
C                IG:      1 FOR INITIAL CHANNEL, 2 FOR EXIT CHANNEL.    SCEL-004
C                NTGS:    NUMBER OF ANGLES.                             SCEL-005
C                JMAX:    NUMBER OF VALUES OF TOTAL ANGULAR MOMENTA.    SCEL-006
C                NTOT:    LENGTH OF WORKING SPACE FOR TGS.              SCEL-007
C                IDMT:    TOTAL LENGTH OF WORKING SPACE.                SCEL-008
C                LO:      LOGICAL CONTROLS.                             SCEL-009
C IN /LIMIT/     TMIN,TMAX:  FIRST AND LAST ANGLE.                      SCEL-010
C                TITRE:   COMMENT.                                      SCEL-011
C                NG:      INDICATIONS FOR GRAPHS.                       SCEL-012
C                MTETA:   NUMBER OF ANGLES.                             SCEL-013
C IN /GARDE/     SK:      WAVE NUMBER.                                  SCEL-014
C                ETA:     COULOMB PARAMETER.                            SCEL-015
C                SGL:     COULOMB PHASE SHIFT.                          SCEL-016
C WORKING SPACE: AF(*,1)  FOR ROTATION MATRIX ELEMENTS.                 SCEL-017
C                AF(*,2-5) FOR PHASE-SHIFTS MULTIPLIED BY COULOMB ONES. SCEL-018
C                TGS      FOR GRAPHS.                                   SCEL-019
C***********************************************************************SCEL-020
      IMPLICIT REAL*8 (A-H,O-Z)                                         SCEL-021
      LOGICAL LO(40)                                                    SCEL-022
      DIMENSION TGS(NTGS,5),SIGNE(2,2),XC(4,1),AR(2),AI(2),AF(JMAX,5)   SCEL-023
      COMMON /LIMIT/ COEF,TMIN,TMAX,TITRE(18),VAL(21,2),NG(8),JMX,MTJ,NJSCEL-024
     1,MPAR,INM,MTETA,NAF,NAMP,NKTF,NCMU,NCH(3),NCZ(3),NCOU,NFA,NFO,NFONSCEL-025
     2,NINT,NFF,NMUL,NPLACE,NQU,NSOM,NT1,NT2,NVT,NFB,JMAX1,LX1,NWF,NMF  SCEL-026
      COMMON /GARDE/ ECM(2),SK(2),ETA(2),AMRED(2),SGL(2)                SCEL-027
      DATA SIGNE/4H INI,4HTIAL,4H** F,4HINAL/                           SCEL-028
      IF (5*NTGS.GT.NTOT) CALL MEMO(IDMT,5*NTGS,NQ,3,LO)                SCEL-029
      IF (LO(19)) GO TO 6                                               SCEL-030
      WRITE (6,1000) TITRE,(SIGNE(M,IG),M=1,2)                          SCEL-031
C CALCULATE THE REACTION CROSS-SECTION                                  SCEL-032
      SX=0.D0                                                           SCEL-033
      AX=2.D0*SGL(IG)                                                   SCEL-034
      DO 1 M=1,JMAX                                                     SCEL-035
      CR=M                                                              SCEL-036
      SX=SX+CR*(XC(2,2*M-1)-XC(1,2*M-1)**2-XC(2,2*M-1)**2+XC(2,2*M)-XC(1SCEL-037
     1,2*M)**2-XC(2,2*M)**2)                                            SCEL-038
      AR(1)=XC(1,2*M-1)*DCOS(AX)-XC(2,2*M-1)*DSIN(AX)                   SCEL-039
      AI(1)=XC(2,2*M-1)*DCOS(AX)+XC(1,2*M-1)*DSIN(AX)                   SCEL-040
      AX=AX+2.D0*DATAN2(ETA(IG),CR)                                     SCEL-041
      AR(2)=XC(1,2*M)*DCOS(AX)-XC(2,2*M)*DSIN(AX)                       SCEL-042
      AI(2)=XC(2,2*M)*DCOS(AX)+XC(1,2*M)*DSIN(AX)                       SCEL-043
      AF(M,2)=CR*(AR(1)+AR(2))/SK(IG)                                   SCEL-044
      AF(M,3)=CR*(AI(1)+AI(2))/SK(IG)                                   SCEL-045
      AF(M,4)=CR*(AR(1)-AR(2))/SK(IG)                                   SCEL-046
    1 AF(M,5)=CR*(AI(1)-AI(2))/SK(IG)                                   SCEL-047
      SX=125.6637D0*SX/SK(IG)**2                                        SCEL-048
C CALCULATION AT EQUIDISTANT ANGLES                                     SCEL-049
      DTM=(TMAX-TMIN)/(NTGS-1.D0)                                       SCEL-050
      CR=0.D0                                                           SCEL-051
      CI=0.D0                                                           SCEL-052
      BR=0.D0                                                           SCEL-053
      DO 5 M=1,MTETA                                                    SCEL-054
      TTETA=TMIN+DTM*(M-1)                                              SCEL-055
      TGS(M,1)=TTETA*180.D0/3.141592653589793D0                         SCEL-056
      AX=DCOS(TTETA*.5D0)                                               SCEL-057
      BX=DSIN(TTETA*.5D0)                                               SCEL-058
      IS=1                                                              SCEL-059
      IF (BX*ETA(IG).EQ.0.D0) GO TO 2                                   SCEL-060
C CALCULATION OF THE COULOMB AMPLITUDE                                  SCEL-061
      CI=2.D0*(-ETA(IG)*DLOG(BX)+SGL(IG))                               SCEL-062
      BR=-ETA(IG)/(2.D0*SK(IG)*BX**2)                                   SCEL-063
      CR=BR*DCOS(CI)                                                    SCEL-064
      CI=BR*DSIN(CI)                                                    SCEL-065
    2 DO 4 K=1,2                                                        SCEL-066
      CALL EMRO(1,1,IS,AX,BX,AF,JMAX)                                   SCEL-067
      AR(K)=CR*AF(1,1)                                                  SCEL-068
      AI(K)=CI*AF(1,1)                                                  SCEL-069
      DO 3 L=1,JMAX                                                     SCEL-070
      AR(K)=AR(K)+AF(L,1)*AF(L,2*K)                                     SCEL-071
    3 AI(K)=AI(K)+AF(L,1)*AF(L,2*K+1)                                   SCEL-072
    4 IS=-IS                                                            SCEL-073
      TGS(M,2)=AR(1)**2+AR(2)**2+AI(1)**2+AI(2)**2                      SCEL-074
      TGS(M,4)=2.D0*(AR(1)*AI(2)-AI(1)*AR(2))/TGS(M,2)                  SCEL-075
      TGS(M,5)=2.D0*(BX*AX*(AR(1)**2+AI(1)**2-AR(2)**2-AI(2)**2)+(AX**2-SCEL-076
     1BX**2)*(AR(1)*AR(2)+AI(1)*AI(2)))/TGS(M,2)                        SCEL-077
      TGS(M,3)=TGS(M,2)                                                 SCEL-078
      IF (BX*ETA(IG).NE.0.D0) TGS(M,3)=TGS(M,3)/BR**2                   SCEL-079
      TGS(M,2)=10.D0*TGS(M,2)                                           SCEL-080
    5 WRITE (6,1001) (TGS(M,L),L=1,5)                                   SCEL-081
      WRITE (6,1002) SX                                                 SCEL-082
      CALL GRAL(TGS,TGS(1,3),MTETA,NG(2*IG+3),1)                        SCEL-083
      WRITE (6,1003)                                                    SCEL-084
      RETURN                                                            SCEL-085
    6 WRITE (6,1004)                                                    SCEL-086
      RETURN                                                            SCEL-087
 1000 FORMAT (1H1,18A4//7H ******,2A4,13H STATE ******///3X,6H ANGLE,3X,SCEL-088
     139H DIF. CROSS SECTION  CR.SEC./RUTHERFORD,8X,12HPOLARISATION,8X,1SCEL-089
     22HOBSERVABLE Q//)                                                 SCEL-090
 1001 FORMAT (3X,F7.2,4D20.7)                                           SCEL-091
 1002 FORMAT (///29H TOTAL REACTION CROSS SECTION,D15.7,11H MILLIBARNS//SCEL-092
     1)                                                                 SCEL-093
 1003 FORMAT (1H1)                                                      SCEL-094
 1004 FORMAT (25H ***** STOP IN SCEL *****)                             SCEL-095
      END                                                               SCEL-096
