C 11/02/98                                                      DWBA98  MULT-000
      SUBROUTINE MULT(AM,INM,CMU,JPREC)                                 MULT-001
C CALCULATES THE MULTIPOLES.                                            MULT-002
C DATA PASSED OVER BY ARGUMENT:                                         MULT-003
C  INM        NUMBER OF INTEGRATION POINTS.                             MULT-004
C  CMU        RANGE OF INTERACTION.                                     MULT-005
C  JPREC      PREVIOUS VALUE OF J.                                      MULT-006
C DATA PASSED OVER BY COMMON /NOMBR/:                                   MULT-007
C  H          INTEGRATION STEP.                                         MULT-008
C  KR         ADDRESS OF THE COULOMB MULTIPOLES OR 0.                   MULT-009
C  KS         NUMBER OF FINITE RANGES.                                  MULT-010
C DATA PASSED OVER BY COMMON /GABJ/:                                    MULT-011
C  JX         VALUE OF THE ANGULAR MOMENTUM J.                          MULT-012
C RESULTS: AM(INM,K,I) MULTIPOLES FOR THE RANGE CMU(I) IF I IS          MULT-013
C      SMALLER OR EQUAL TO KR. THESE MULTIPOLES ARE THE IRREGULAR MULTI-MULT-014
C      POLES V(J-3) TO V(J+3) FOR K=1 TO 7 AND THE REGULAR MULTIPOLES   MULT-015
C      V(J-3) TO V(J+7) FOR K=8 TO 18. THE MULTIPOLES FOR NEGATIVE      MULT-016
C      VALUES OF J ARE ZERO. THE REGULAR MULTIPOLES ARE MULTIPLIED BY   MULT-017
C      THE STEP SIZE. THESE MULTIPOLES ARE NORMALISED TO THE LAST       MULT-018
C      VALUE OF THE IRREGULAR MULTIPOLE EQUAL TO RANGE/R FOR J=0.       MULT-019
C      IN ADDITION THE REGULAR MULTIPOLES ARE MULTIPLIED BY EXP(70.) ANDMULT-020
C      THE IRREGULAR MULTIPOLES DIVIDED BY THE SAME VALUE. NEAR THE     MULT-021
C      ORIGIN, THE MULTIPOLES FOR POINTS INVOLVING AN EXPONENTIAL >85.  MULT-022
C      ( >155. IN TOTAL) ARE CANCELLED. IF THE LAST VALUE OF THE REGULARMULT-023
C      MULTIPOLE V(J) IS LESS THAN 1.E25, THE REGULAR MULTIPOLES ARE    MULT-024
C      MULTIPLIED BY 1.E5 AND THE IRREGULAR MULTIPOLES BY 1.E-5 . IF,   MULT-025
C      FOR A POINT, THE IRREGULAR MULTIPOLE IS LARGER THAN 1.E35, ALL   MULT-026
C      THE MULTIPOLES FOR THAT RANGE THAT POINT ARE CANCELLED.          MULT-027
C**** FOR J=0, THIS ALLOWS MATCHING RADII OF UP TO 150 TIMES THE        MULT-028
C SMALLEST NON-ZERO RANGE TO BE USED. FOR THE THE POSITIVE VALUES OF J  MULT-029
C THE MULTIPOLES AT THE FIRST POINTS ARE CANCELLED BUT THE FUNCTIONS    MULT-030
C Y ARE VERY SMALL DUE TO THEIR LARGE ANGULAR MOMENTUM.                 MULT-031
C ON IBM OR UNIVAC, THE VALUES 70. AND 85. CAN BE DOUBLED AND THE OTHER MULT-032
C CONSTANTS SQUARED. ON  CDC, THESE VALUES CAN BE GREATLY INCREASED.****MULT-033
C            COULOMB MULTIPOLES FOR I=KR, IRREGULAR FOR I=1 AND         MULT-034
C      REGULAR FOR I=2. THE REGULAR MULTIPOLE IS NORMALISED SO THAT ITS MULT-035
C      MAXIMUM IS EQUAL TO 1, THE IRREGULAR MULTIPOLE IS CANCELLED IF   MULT-036
C      REGULAR IS SMALLER THAN 1.E-20.                                  MULT-037
C  VARIOUS CONSTANTS ONLY DEPEND ON J: AJ,BJ,CJ,DJ                      MULT-038
C SIGNIFICANCE OF THE QUANTITIES IN COMMON /GABJ/                       MULT-039
C    AA,AB            DIFFERENCE AND SUM OF EIGENVALUES OF 1.+(L.S).    MULT-040
C    AJ,BJ,CJ         JX, JX*(JX+1), 2*JX+1.                            MULT-041
C    DJ               1./(JX*(JX+1)) OR 1. IF JX=0.                     MULT-042
C    XG(11)           DIFFERENT PRODUCTS OF AA AND BB COMPUTED IN GEOM. MULT-043
C    JX               SPIN TRANSFER.                                    MULT-044
C***********************************************************************MULT-045
      IMPLICIT REAL*8 (A-H,O-Z)                                         MULT-046
      LOGICAL LO                                                        MULT-047
      DIMENSION AM(INM,18,1),CMU(1)                                     MULT-048
      COMMON /NOMBR/ H,CCO(5),JMAX,KV,KR,KS,NBCONF,NBPROT,J,KY,ILL(3,4),MULT-049
     1LO(40)                                                            MULT-050
      COMMON /GABJ/ AA,AB,AJ,BJ,CJ,DJ,XG(11),JX                         MULT-051
      JP=JX+1                                                           MULT-052
      IF (KR.EQ.0) GO TO 2                                              MULT-053
C CALCULATE THE COULOMB MULTIPOLES                                      MULT-054
      AR=0.D0                                                           MULT-055
      AK=H*INM                                                          MULT-056
      AH=2*JX+1                                                         MULT-057
      DO 1 I=1,INM                                                      MULT-058
      AR=AR+H                                                           MULT-059
      AM(I,2,KR)=(AR/AK)**JX                                            MULT-060
      AM(I,1,KR)=0.D0                                                   MULT-061
      IF (AM(I,2,KR).GT.1.D-20) AM(I,1,KR)=H/(AM(I,2,KR)*AH*AR)         MULT-062
    1 CONTINUE                                                          MULT-063
    2 IF (KS.EQ.0) GO TO 18                                             MULT-064
C CALCULATE MULTIPOLES FOR A YUKAWA FORM-FACTOR                         MULT-065
      J1=JPREC+2                                                        MULT-066
      DO 17 K1=1,KS                                                     MULT-067
      AH=H/CMU(K1)                                                      MULT-068
      AR=0.D0                                                           MULT-069
      AX=AH*INM-70.D0                                                   MULT-070
      DO 12 I=1,INM                                                     MULT-071
      AR=AR+AH                                                          MULT-072
      DO 11 JJ=J1,JP                                                    MULT-073
      IF (JJ.NE.1) GO TO 6                                              MULT-074
C STARTING VALUES AND RESULTS FOR JX=0                                  MULT-075
      IF (AX-AR.LT.85.D0) GO TO 5                                       MULT-076
    3 DO 4 K=1,18                                                       MULT-077
    4 AM(I,K,K1)=0.D0                                                   MULT-078
      WRITE (6,1000) I,JJ,K1,CMU(K1)                                    MULT-079
      GO TO 12                                                          MULT-080
    5 AM(I,1,K1)=0.D0                                                   MULT-081
      AM(I,2,K1)=0.D0                                                   MULT-082
      AM(I,3,K1)=0.D0                                                   MULT-083
      AM(I,4,K1)=DEXP(AX-AR)/AR                                         MULT-084
      AM(I,5,K1)=-AM(I,4,K1)*(1.D0/AR+1.D0)                             MULT-085
      AM(I,6,K1)=AM(I,4,K1)-AM(I,5,K1)*3.D0/AR                          MULT-086
      AM(I,7,K1)=AM(I,5,K1)-AM(I,6,K1)*5.D0/AR                          MULT-087
      AM(I,8,K1)=0.D0                                                   MULT-088
      AM(I,9,K1)=0.D0                                                   MULT-089
      AM(I,10,K1)=0.D0                                                  MULT-090
      AM(I,11,K1)=H*(DEXP(AR-AX)-DEXP(-AR-AX))/(2.D0*AR)                MULT-091
      GO TO 8                                                           MULT-092
C TRANSFER OF THE REGULAR AND UPWARD RECURSION FOR IRREGULAR            MULT-093
    6 DO 7 M=1,17                                                       MULT-094
    7 AM(I,M,K1)=AM(I,M+1,K1)                                           MULT-095
      AM(I,7,K1)=AM(I,5,K1)-AM(I,6,K1)*(2*JJ+3)/AR                      MULT-096
      IF (ABS(AM(I,7,K1)).GT.1.E35) GO TO 3                             MULT-097
      IF (MOD(JJ,5).NE.1) GO TO 11                                      MULT-098
C DOWNWARDS RECURSION FOR ELEVEN REGULAR FUNCTION                       MULT-099
    8 AQ=DMAX1(JJ+7.D0,DSQRT(10.5D0*AR)-0.5D0)                          MULT-100
      K=INT(AQ+3.D0+21.D0*AR/(AQ+AQ+1.D0))                              MULT-101
      AK=0.D0                                                           MULT-102
    9 AK=AR/(2.D0*K+1.D0+AR*AK)                                         MULT-103
      IF (K.LE.JJ+6) AM(I,K-JJ+12,K1)=AK                                MULT-104
      K=K-1                                                             MULT-105
      IF (K.GE.JJ) GO TO 9                                              MULT-106
      DO 10 M=12,18                                                     MULT-107
   10 AM(I,M,K1)=-AM(I,M-1,K1)*AM(I,M,K1)                               MULT-108
   11 CONTINUE                                                          MULT-109
   12 CONTINUE                                                          MULT-110
   13 IF (ABS(AM(INM,11,K1)).GT.1.D25) GO TO 17                         MULT-111
C RENORMALISATION FOR TOO SMALL REGULAR MULTIPOLE                       MULT-112
      IF (.NOT.LO(7)) WRITE (6,1001) K1,JX                              MULT-113
      DO 16 I=1,INM                                                     MULT-114
      DO 14 K=1,7                                                       MULT-115
   14 AM(I,K,K1)=AM(I,K,K1)*1.D-5                                       MULT-116
      DO 15 K=8,18                                                      MULT-117
   15 AM(I,K,K1)=AM(I,K,K1)*1.D5                                        MULT-118
   16 CONTINUE                                                          MULT-119
      GO TO 13                                                          MULT-120
   17 CONTINUE                                                          MULT-121
C CONSTANTS WHICH DEPEND ONLY ON JX                                     MULT-122
   18 AJ=JX                                                             MULT-123
      BJ=AJ*(AJ+1.D0)                                                   MULT-124
      CJ=2.D0*AJ+1.D0                                                   MULT-125
      DJ=BJ                                                             MULT-126
      IF (DJ.NE.0.D0) DJ=1.D0/DJ                                        MULT-127
      RETURN                                                            MULT-128
 1000 FORMAT (29H IMPOSSIBLE TO CALCULATE THE ,I5,26HTH POINT OF THE MULMULT-129
     1TIPOLE ,I3,8H OF THE ,I3,17HTH RANGE WHICH IS,F10.5)              MULT-130
 1001 FORMAT (37H ****** RENORMALISATION OF MULTIPOLES,I3,8H FOR J =,I3)MULT-131
      END                                                               MULT-132
