C 11/12/99                                                      DWBA98  PTIP-000
      SUBROUTINE PTIP(KTF,CMU,CVF,VX,AM,VS,VD,VT,INM,NT,CA)             PTIP-001
C CALCULATION OF THE FORM-FACTORS IN THE HELICITY FORMALISM FOR NATURAL PTIP-002
C PARITY MATRIX-ELEMENTS.                                               PTIP-003
C INPUTS PASSED AS ARGUMENTS:                                           PTIP-004
C    KTF,CMU,CVF DESCRIPTION OF THE INTERACTION (SEE LEC2).             PTIP-005
C    VX(INM,*) ARE THE RADIAL DEPENDENCES.                              PTIP-006
C    AM(INM,18,*) ARE THE MULTIPOLES.                                   PTIP-007
C    AM(INM,J,K) FOR THE RANGE CMU(K) IF K IS LESS THAN OR EQUAL TO KS  PTIP-008
C          IRREGULAR FUNCTIONS J-3 TO J+3 FOR J=1,7, REGULAR FUNCTIONS  PTIP-009
C          J-3 TO J+7 FOR J=8,18.                                       PTIP-010
C          FOR K=KR, COULOMB MULTIPOLES IRREGULAR FOR J=1               PTIP-011
C                                       REGULAR FOR J=2.                PTIP-012
C  VD(INM,I) IF LO(7)=.FALSE., R AND R**2 FOR I=1 AND 2                 PTIP-013
C            IF LO(7)=.TRUE., HOLE FUNCTION FOR I=5, PARTICLE FUNCTION  PTIP-014
C            FOR I=2, FIRST AND SECOND DERIVATIVES OF PARTICLE FUNCTION PTIP-015
C            FOR I=3 AND 4.                                             PTIP-016
C  VT(INM,I) IF LO(7)=.FALSE., REAL AND IMAGINARY PARTS OF THE PRODUCT  PTIP-017
C            OF THE WAVE FUNCTIONS FOR I=1,2                            PTIP-018
C            PRODUCT WITH FIRST DERIVATIVE OF THE FUNCTIONS FOR I=3,4.  PTIP-019
C            PRODUCT WITH SECOND DERIVATIVE OF THE FUNCTIONS FOR I=5,6. PTIP-020
C            IF LO(7)=.TRUE., XA(INM,INM,8) FOR NON LOCAL POTENTIALS.   PTIP-021
C  INM       IS THE NUMBER OF INTEGRATION POINTS.                       PTIP-022
C  NT        INDICATION OF THE NATURE OF THE PARTICLES.                 PTIP-023
C              1 - IDENTICAL                                            PTIP-024
C              2 - DIFFERENT, DIRECT TERM                               PTIP-025
C              3 - DIFFERENT, EXCHANGE TERM                             PTIP-026
C  CA        COEFFICIENT OF THE CONFIGURATION MULTIPLIED BY THE COEFFI- PTIP-027
C            CIENT G OF FORMULA (35) OF REFERENCE 1.                    PTIP-028
C DATA PASSED OVER BY THE COMMON /NOMBR/:                               PTIP-029
C  H         INTEGRATION STEP.                                          PTIP-030
C  CCO(I)    COULOMB INTERACTION WITH  PROTONS AND NEUTRONS             PTIP-031
C            FOR THE DIRECT AND EXCHANGE TEMS FOR I=1,4.                PTIP-032
C  KR        ADDRESS OF THE COULOMB MULTIPOLES.                         PTIP-033
C  KS        NUMBER OF FINITE RANGES.                                   PTIP-034
C  NBPROT    NUMBER OF SINGLE PARTICLE STATES OF THE SAME TYPE AS THE   PTIP-035
C            INCIDENT PARTICLE.                                         PTIP-036
C  KY        NUMBER OF DIFFERENT RADIAL DEPENDENCES.                    PTIP-037
C  LO        LOGICAL CONTROLS: LO(7)=.TRUE. COMPUTATION OF POTENTIAL.   PTIP-038
C                              LO(16)=.TRUE. COULOMB INTERACTION.       PTIP-039
C                              LO(22)=.TRUE. EXCHANGE CALCULATION.      PTIP-040
C DATA PASSED OVER BY THE COMMON /GABJ/: C  AJ,BJ,CJ,DJ  SPIN TRANSFER JPTIP-041
C  XG           VARIOUS DEPENDENCES ON QUANTUM NUMBERS                  PTIP-042
C RESULTS:                                                              PTIP-043
C  VD(INM,I) FORM-FACTORS                                               PTIP-044
C MEANING OF THE LOGICALS INTERNAL TO THE SUBROUTINE:                   PTIP-045
C LOO(1) ARITHMETIC AVERAGE   LOO(2) SECOND TIME FOR ARITHM. AVERAGE    PTIP-046
C LOO(3) DENSITY DEPENDENCE OF MIDDLE POINT                             PTIP-047
C LOO(4) PREVIOUS STEPS WERE NOT DONE AGAIN  LOO(5) SAME FORM FACTOR    PTIP-048
C LOO(6) USED IN PTIV   LOO(7) FOR SAME LENGTH AS IN PTII               PTIP-049
C WORKING AREAS:  VT(,I) FOR I=7 TO 16                                  PTIP-050
C PRODUCT OF PARTICLE-HOLE FUNCTIONS IN (1,2)                           PTIP-051
C PRODUCT OF PARTICLE AND FIRST DERIVATIVE OF HOLE FUNCTION IN (3,4)    PTIP-052
C PRODUCT OF PARTICLE AND SECOND DERIVATIVE OF HOLE FUNCTION IN (5,6)   PTIP-053
C VT(IA,IA+1) MULTIPLIED BY THE FORM-FACTOR IS IN VT(7,8)               PTIP-054
C VT(IB,IB+1) MULTIPLIED BY THE POWER OF R1 IS IN VT(9,10)              PTIP-055
C VT(IC,IC+1) INTEGRATED WITH THE MULTIPOLE IK IS IN VT(11,12)          PTIP-056
C VT(11,12) MULTIPLIED BY THE FORM FACTOR IS IN VT(13,14)               PTIP-057
C VT(ID,ID+1) MULTIPLIED BY THE POWER OF R2 IS IN VT(15,16)             PTIP-058
C THE RESULT IS IN VT(IE,IE+1)                                          PTIP-059
C VT(IH,IH+1) PRODUCT OF FUNCTIONS WITH FORM-FACTORS IS IN VT(17,18)    PTIP-060
C R1 INTEGRATED VARIABLE, R2 FACTOR VARIABLE                  ORDER OF  PTIP-061
C MULTIPOLES                         J-2 J-1  J  J+1 J+2     OPERATIONS PTIP-062
C  VT(1,2)             FROM VD(1)    1-12   13-24   25-36  |  1   3   6 PTIP-063
C  R2 VT(1,2)          FROM VD(25) 223-228 229-234 235-240 |  2   4   7 PTIP-064
C  R2**2 VT(1,2)       FROM VD(3)          249-249         |      5     PTIP-065
C  R1 VT(1,2)          FROM VD(25)     193-198 199-204     |    8  11   PTIP-066
C  R1/R2 VT(1,2)       FROM VD(1)       97-108 109-120     |    9  12   PTIP-067
C  R2*R1 VT(1,2)       FROM VD(3)      247-247 248-248     |   10  13   PTIP-068
C  R1**2 VT(1,2)       FROM VD(37) 241-242 243-244 245-246 | 14  17  21 PTIP-069
C  R1**2 VT(1,2)       FROM VD(3)          250-250         |     18     PTIP-070
C  R1**2/R2 VT(1,2)    FROM VD(25) 205-210 211-216 217-222 | 15  19  22 PTIP-071
C  R1**2/R2**2 VT(1,2) FROM VD(1)  121-132 133-144 145-156 | 16  20  23 PTIP-072
C  R2/R1 VT(1,2)       FROM VD(1)       37-48   49-60      |   24  25   PTIP-073
C  R2**2/R1**2 VT(1,2) FROM VD(1)   61-72   73-84   85-96  | 26  27  28 PTIP-074
C  -R2 VT(3,4)         FROM VD(1)      193-198 199-204     |   29  30   PTIP-075
C  R1 VT(3,4)          FROM VD(1)  157-162 163-168 169-174 | 31  33  35 PTIP-076
C  -2 R2 R1 VT(3,4)    FROM VD(25) 241-242 243-244 245-246 | 32  34  36 PTIP-077
C  R2**2/R1 VT(3,4)    FROM VD(1)  175-180 181-186 187-192 | 37  38  39 PTIP-078
C  R2**2 VT(5,6)       FROM VD(1)  241-242 243-244 245-246 | 40  41  42 PTIP-079
C***********************************************************************PTIP-080
      IMPLICIT REAL*8 (A-H,O-Z)                                         PTIP-081
      LOGICAL LO,LOO(6)                                                 PTIP-082
      DIMENSION VT(INM,12),AM(INM,18,1),KTF(7,7,1),CMU(1),CVF(7,6,1),VX(PTIP-083
     1INM,1),VS(INM,2),VD(INM,2),VA(2,7),BB(42),IBD(42),IBF(42),IBK(42),PTIP-084
     2IBA(42),IB1(42),IB2(42),IBT(42),XX(2,250),X0(2,12,13),X1(2,6,14),XPTIP-085
     32(2,2,3),X3(2,4),S0(3,12,13),S1(3,6,14),S2(3,2,3),ST(3,246),IBB(42PTIP-086
     4,7),XH(11),JBA(42),JBT(42)                                        PTIP-087
      EQUIVALENCE (XX(1,1),X0(1,1,1)),(XX(1,157),X1(1,1,1)),(XX(1,241),XPTIP-088
     12(1,1,1)),(XX(1,247),X3(1,1)),(ST(1,1),S0(1,1,1)),(ST(1,157),S1(1,PTIP-089
     21,1)),(ST(1,241),S2(1,1,1)),(IBB(1,1),IBD),(IBB(1,2),IBF),(IBB(1,3PTIP-090
     3),IBK),(IBB(1,4),JBA),(IBB(1,5),IB1),(IBB(1,6),IB2),(IBB(1,7),JBT)PTIP-091
      COMMON /NOMBR/ H,CCO(5),JMAX,KV,KR,KS,NBCONF,NBPROT,J,KY,ILL(3,4),PTIP-092
     1LO(40)                                                            PTIP-093
      COMMON /GABJ/ AA,AB,AJ,BJ,CJ,DJ,XG(11),JX                         PTIP-094
      DATA BB /28*1.,2*-1.,1.,-2.,1.,-2.,1.,-2.,6*1./                   PTIP-095
      DATA XH /-1.,1.,-1.,3*1.,2*-1.,1.,2*-1./                          PTIP-096
      DATA JBA /28*1,11*2,3*3/                                          PTIP-097
      DATA JBT /1,3,1,3,-1,1,3,3,1,-1,3,1,-1,5,3,1,5,-1,3,1,5,3,9*1,3,1,PTIP-098
     13,1,3,6*1/                                                        PTIP-099
      DATA IBD /1,223,13,229,249,25,235,193,97,247,199,109,248,241,205,1PTIP-100
     121,243,250,211,133,245,217,145,37,49,61,73,85,193,199,157,241,163,PTIP-101
     2243,169,245,175,181,187,241,243,245/                              PTIP-102
      DATA IBF /12,228,24,234,249,36,240,198,108,247,204,120,248,242,210PTIP-103
     1,132,244,250,216,144,246,222,156,48,60,72,84,96,198,204,162,242,16PTIP-104
     28,244,174,246,180,186,192,242,244,246/                            PTIP-105
      DATA IBK /2*2,3*4,2*6,3*3,3*5,3*2,4*4,3*6,3,5,2,4,6,3,5,2*2,2*4,2*PTIP-106
     16,2,4,6,2,4,6/                                                    PTIP-107
      DATA IBA,IK,IS1 /28*1,11*3,3*5,2*0/                               PTIP-108
      DATA IB1 /7*0,6*1,10*2,2*-1,3*-2,2*0,6*1,3*-1,3*0/                PTIP-109
      DATA IB2 /0,1,0,1,2,0,1,0,-1,1,0,-1,1,0,-1,-2,0,0,-1,-2,0,-1,-2,2*PTIP-110
     11,3*2,2*1,0,1,0,1,0,1,6*2/                                        PTIP-111
      DATA IBT /1,25,1,25,3,1,25,25,1,3,25,1,3,37,25,1,37,3,25,1,37,25,9PTIP-112
     1*1,25,1,25,1,25,6*1/                                              PTIP-113
      CB=CA/CJ                                                          PTIP-114
      IF (LO(7).OR.(.NOT.LO(22))) GO TO 3                               PTIP-115
C ZERO ARRAY FOR THE EXCHANGE CASE.                                     PTIP-116
      DO 2 L=1,40                                                       PTIP-117
      DO 1 I=1,INM                                                      PTIP-118
    1 VD(I,L)=0.D0                                                      PTIP-119
    2 CONTINUE                                                          PTIP-120
    3 IF (KS.EQ.0) GO TO 42                                             PTIP-121
      CALL PTCP(KTF(1,NT,1),KS,H,S0,S1,S2)                              PTIP-122
C LOOP OVER RADIAL DEPENDENCES                                          PTIP-123
      DO 41 KX=1,KY                                                     PTIP-124
      KZ=KX-1                                                           PTIP-125
C LOOP OVER RANGES                                                      PTIP-126
      DO 40 K=1,KS                                                      PTIP-127
      DO 4 I=1,14                                                       PTIP-128
    4 VA(I,1)=0.D0                                                      PTIP-129
      IX=0                                                              PTIP-130
C LOOP OVER THE INTERACTIONS FOR SUM OF THEIR STRENGTHS                 PTIP-131
      DO 5 JJ=1,7                                                       PTIP-132
      IF (KTF(JJ,NT,K).NE.KX) GO TO 5                                   PTIP-133
      IX=JJ                                                             PTIP-134
      VA(1,JJ)=VA(1,JJ)+CB*CVF(JJ,NT,K)                                 PTIP-135
      VA(2,JJ)=VA(2,JJ)+CB*CVF(JJ,NT+3,K)                               PTIP-136
    5 CONTINUE                                                          PTIP-137
      IF (IX.EQ.0) GO TO 40                                             PTIP-138
      KW=KTF(IX,NT+3,K)-1                                               PTIP-139
      DO 9 L=1,2                                                        PTIP-140
      DO 6 I=1,250                                                      PTIP-141
    6 XX(L,I)=0.D0                                                      PTIP-142
      A=.25D0*(VA(L,1)+3.D0*VA(L,2))                                    PTIP-143
      VA(L,2)=.25D0*(VA(L,1)-VA(L,2))*XG(1)*DJ*CJ                       PTIP-144
      VA(L,1)=A*CJ                                                      PTIP-145
      VA(L,3)=VA(L,3)-.5D0*VA(L,5)                                      PTIP-146
      X0(L,1,2)=VA(L,1)                                                 PTIP-147
      X0(L,2,2)=VA(L,2)                                                 PTIP-148
      IF (IX.LE.2) GO TO 9                                              PTIP-149
C SPIN-ORBIT AND TENSOR CONSTANTS                                       PTIP-150
      IF (JX.EQ.0) GO TO 7                                              PTIP-151
      X3(L,1)=-VA(L,4)*XG(1)*DJ*(CJ+2.D0)                               PTIP-152
      X3(L,2)=-VA(L,4)*XG(1)*DJ*(CJ-2.D0)                               PTIP-153
      X3(L,3)=VA(L,4)*XG(1)*DJ*CJ                                       PTIP-154
      X3(L,4)=VA(L,4)*XG(1)*DJ*CJ                                       PTIP-155
      X1(L,1,7)=VA(L,3)*.25D0*XG(1)/H                                   PTIP-156
      X1(L,2,7)=-VA(L,3)*.25D0/H                                        PTIP-157
      X1(L,1,8)=-VA(L,3)*.25D0*XG(1)/H                                  PTIP-158
      X1(L,2,8)=VA(L,3)*.25D0/H                                         PTIP-159
      X0(L,2,2)=X0(L,2,2)+.125D0*VA(L,3)*(2.D0*XG(1)-XG(3))*CJ*DJ       PTIP-160
      X0(L,4,2)=-.125D0*VA(L,3)*XG(1)*CJ*DJ                             PTIP-161
      X0(L,1,9)=-.125D0*VA(L,3)*(AJ-1.D0)*(AJ-XG(1))                    PTIP-162
      X0(L,2,9)=-.125D0*VA(L,3)*(AJ-1.D0+XG(1)*DJ*(AJ+1.D0))            PTIP-163
      X0(L,3,9)=.125D0*VA(L,3)                                          PTIP-164
      X0(L,4,9)=.125D0*VA(L,3)*XG(1)*DJ*(AJ+1.D0)                       PTIP-165
      X0(L,5,9)=-.125D0*VA(L,3)*AJ                                      PTIP-166
      X0(L,2,10)=-.125D0*VA(L,3)*((AJ+2.D0)+XG(1)/(AJ+1.D0))            PTIP-167
      X0(L,3,10)=-.125D0*VA(L,3)                                        PTIP-168
      X0(L,4,10)=.125D0*VA(L,3)*XG(1)/(AJ+1.D0)                         PTIP-169
      X0(L,1,4)=-.125D0*VA(L,3)*((AJ-1.D0)*(AJ+XG(1))-XG(2)+AJ*XG(4))   PTIP-170
      X0(L,2,4)=.125D0*VA(L,3)*(AJ-1.D0-(XG(1)-XG(3))*DJ*(AJ+1.D0))     PTIP-171
      X0(L,2,5)=.125D0*VA(L,3)*(AJ+2.D0-(XG(1)-XG(3))/(AJ+1.D0))        PTIP-172
    7 X0(L,1,2)=X0(L,1,2)+VA(L,3)*(.125D0*XG(4)-.5D0)*CJ                PTIP-173
      X0(L,5,2)=.125D0*VA(L,3)*CJ                                       PTIP-174
      X0(L,1,10)=.125D0*VA(L,3)*(AJ+2.D0)*(AJ+1.D0+XG(1))               PTIP-175
      X0(L,5,10)=-.125D0*VA(L,3)*(AJ+1.D0)                              PTIP-176
      X0(L,1,5)=.125D0*VA(L,3)*((AJ+2.D0)*(AJ+1.D0-XG(1))-XG(2)-(AJ+1.D0PTIP-177
     1)*XG(4))                                                          PTIP-178
      IF (IX.LE.4) GO TO 9                                              PTIP-179
C CHANGE FROM S=0 OR S=1 TO CTE AND S1.S2                               PTIP-180
      IF (LO(25)) VA(L,7)=VA(L,7)-VA(L,5)                               PTIP-181
      A=.5D0*VA(L,5)                                                    PTIP-182
      VA(L,5)=A+.25D0*VA(L,6)+.75D0*VA(L,7)                             PTIP-183
      VA(L,7)=.25D0*(VA(L,7)-VA(L,6))                                   PTIP-184
      VA(L,6)=A                                                         PTIP-185
      DO 8 I=1,246                                                      PTIP-186
    8 XX(L,I)=XX(L,I)+VA(L,5)*ST(1,I)+VA(L,6)*ST(2,I)+VA(L,7)*ST(3,I)   PTIP-187
    9 CONTINUE                                                          PTIP-188
      LOO(1)=KTF(IX,7,K).GT.0                                           PTIP-189
      LOO(2)=.FALSE.                                                    PTIP-190
      LOO(3)=KTF(IX,7,K).LT.0                                           PTIP-191
      IF ((.NOT.LO(7)).OR.(.NOT.LO(22))) GO TO 10                       PTIP-192
      CALL PTIV(K,AM,CMU,H,LOO,IBB,BB,42,XX,VD,VS,VX,VT,INM,KW,XH,KZ)   PTIP-193
      GO TO 40                                                          PTIP-194
   10 LOO(4)=.FALSE.                                                    PTIP-195
      IH=1                                                              PTIP-196
      IA=0                                                              PTIP-197
      DO 39 JJ=1,42                                                     PTIP-198
      J1=IBD(JJ)                                                        PTIP-199
      J2=IBF(JJ)                                                        PTIP-200
      LOO(5)=.FALSE.                                                    PTIP-201
      DO 38 JB=J1,J2                                                    PTIP-202
      IF ((XX(1,JB).EQ.0.).AND.(XX(2,JB).EQ.0.)) GO TO 38               PTIP-203
      IF (LOO(5)) GO TO 34                                              PTIP-204
      LOO(4)=IA.EQ.IBA(JJ)                                              PTIP-205
      IF (LOO(4)) GO TO 15                                              PTIP-206
      IA=IBA(JJ)                                                        PTIP-207
      IB=IA                                                             PTIP-208
      IF (KZ.EQ.0.OR.LOO(2).OR.LOO(3)) GO TO 15                         PTIP-209
C MULTIPLICATION BY THE RADIAL DEPENDENCES                              PTIP-210
      IB=7                                                              PTIP-211
      IKX=1                                                             PTIP-212
      IX=IA                                                             PTIP-213
      IY=IB                                                             PTIP-214
   11 DO 12 I=1,INM                                                     PTIP-215
      VT(I,IY)=VT(I,IX)*VX(I,KZ)                                        PTIP-216
   12 VT(I,IY+1)=VT(I,IX+1)*VX(I,KZ)                                    PTIP-217
      IF (KW.EQ.KZ) GO TO 14                                            PTIP-218
      DO 13 I=1,INM                                                     PTIP-219
      VT(I,IY)=VT(I,IY)-VT(I,IX+1)*VX(I,KW)                             PTIP-220
   13 VT(I,IY+1)=VT(I,IY+1)+VT(I,IX)*VX(I,KW)                           PTIP-221
   14 GO TO ( 15 , 24 , 33 ) , IKX                                      PTIP-222
   15 LOO(4)=LOO(4).AND.(IS1.EQ.IB1(JJ))                                PTIP-223
      IF (LOO(4)) GO TO 21                                              PTIP-224
      IS1=IB1(JJ)                                                       PTIP-225
      IX=IB                                                             PTIP-226
      IY=9                                                              PTIP-227
      IC=IX                                                             PTIP-228
      IF (IS1.EQ.0) GO TO 21                                            PTIP-229
      IS=IS1                                                            PTIP-230
      IC=9                                                              PTIP-231
      IKX=1                                                             PTIP-232
C MULTIPLICATION BY A POWER OF R                                        PTIP-233
   16 IF (IS.LT.0) GO TO 18                                             PTIP-234
      DO 17 I=1,INM                                                     PTIP-235
      VT(I,IY)=VT(I,IX)*VS(I,IS)                                        PTIP-236
   17 VT(I,IY+1)=VT(I,IX+1)*VS(I,IS)                                    PTIP-237
      GO TO 20                                                          PTIP-238
   18 IS=-IS                                                            PTIP-239
      DO 19 I=1,INM                                                     PTIP-240
      VT(I,IY)=VT(I,IX)/VS(I,IS)                                        PTIP-241
   19 VT(I,IY+1)=VT(I,IX+1)/VS(I,IS)                                    PTIP-242
   20 IF (IKX.GE.2) GO TO 34                                            PTIP-243
   21 LOO(4)=LOO(4).AND.(IK.EQ.IBK(JJ))                                 PTIP-244
      IF (LOO(4)) GO TO 33                                              PTIP-245
      ID=11                                                             PTIP-246
      IK=IBK(JJ)                                                        PTIP-247
      IKX=2                                                             PTIP-248
      IF (LOO(3)) GO TO 25                                              PTIP-249
C COMPUTATION OF A MULTIPOLE                                            PTIP-250
      VT(INM,11)=0.D0                                                   PTIP-251
      VT(INM,12)=0.D0                                                   PTIP-252
      I=INM                                                             PTIP-253
      DO 22 L=2,INM                                                     PTIP-254
      VT(I-1,11)=VT(I,11)+AM(I,IK,K)*VT(I,IC)                           PTIP-255
      VT(I-1,12)=VT(I,12)+AM(I,IK,K)*VT(I,IC+1)                         PTIP-256
   22 I=I-1                                                             PTIP-257
      Z1=0.D0                                                           PTIP-258
      Y1=0.D0                                                           PTIP-259
      DO 23 I=1,INM                                                     PTIP-260
      Z1=Z1+AM(I,IK+7,K)*VT(I,IC)                                       PTIP-261
      Y1=Y1+AM(I,IK+7,K)*VT(I,IC+1)                                     PTIP-262
      VT(I,11)=VT(I,11)*AM(I,IK+7,K)+Z1*AM(I,IK,K)                      PTIP-263
   23 VT(I,12)=VT(I,12)*AM(I,IK+7,K)+Y1*AM(I,IK,K)                      PTIP-264
      IH=IC                                                             PTIP-265
      IF ((KZ.EQ.0).OR.(LOO(1).AND.(.NOT.LOO(2)))) GO TO 33             PTIP-266
      IX=11                                                             PTIP-267
      IY=13                                                             PTIP-268
      GO TO 11                                                          PTIP-269
   24 ID=13                                                             PTIP-270
      IF ((JB.NE.13).AND.(JB.NE.14)) GO TO 33                           PTIP-271
      IKX=3                                                             PTIP-272
      IX=IB                                                             PTIP-273
      IY=17                                                             PTIP-274
      IH=17                                                             PTIP-275
      GO TO 11                                                          PTIP-276
   25 DO 31 I=1,INM                                                     PTIP-277
      VT(I,11)=0.D0                                                     PTIP-278
      VT(I,12)=0.D0                                                     PTIP-279
      DO 30 L=1,INM                                                     PTIP-280
      IF (I.GT.L) GO TO 26                                              PTIP-281
      XX1=VT(L,IC)*AM(L,IK,K)*AM(I,IK+7,K)                              PTIP-282
      YY1=VT(L,IC+1)*AM(L,IK,K)*AM(I,IK+7,K)                            PTIP-283
      GO TO 27                                                          PTIP-284
   26 XX1=VT(L,IC)*AM(I,IK,K)*AM(L,IK+7,K)                              PTIP-285
      YY1=VT(L,IC+1)*AM(I,IK,K)*AM(L,IK+7,K)                            PTIP-286
   27 IF (KZ.EQ.KW) GO TO 28                                            PTIP-287
      XX2=XX1*VX(I+L,KZ)-YY1*VX(I+L,KW)                                 PTIP-288
      YY2=YY1*VX(I+L,KZ)+XX1*VX(I+L,KW)                                 PTIP-289
      GO TO 29                                                          PTIP-290
   28 XX2=XX1*VX(I+L,KZ)                                                PTIP-291
      YY2=YY1*VX(I+L,KZ)                                                PTIP-292
   29 VT(I,11)=VT(I,11)+XX2                                             PTIP-293
   30 VT(I,12)=VT(I,12)+YY2                                             PTIP-294
   31 CONTINUE                                                          PTIP-295
      IF ((JB.NE.13).AND.(JB.NE.14)) GO TO 33                           PTIP-296
      IH=17                                                             PTIP-297
      DO 32 I=1,INM                                                     PTIP-298
      VT(I,IH)=VT(I,IC)*VX(2*I,KZ)                                      PTIP-299
      VT(I,IH+1)=VT(I,IC+1)*VX(2*I,KZ)                                  PTIP-300
      IF (KZ.EQ.KW) GO TO 32                                            PTIP-301
      VT(I,IH)=VT(I,IH)-VT(I,IC+1)*VX(2*I,KW)                           PTIP-302
      VT(I,IH+1)=VT(I,IH+1)+VT(I,IC)*VX(2*I,KW)                         PTIP-303
   32 CONTINUE                                                          PTIP-304
   33 IE=ID                                                             PTIP-305
      IS=IB2(JJ)                                                        PTIP-306
      IF (IS.EQ.0) GO TO 34                                             PTIP-307
      IY=15                                                             PTIP-308
      IX=IE                                                             PTIP-309
      IE=IY                                                             PTIP-310
      GO TO 16                                                          PTIP-311
   34 IG=IBT(JJ)+2*(JB-J1)                                              PTIP-312
      LOO(5)=.TRUE.                                                     PTIP-313
      IF ((JB.NE.13).AND.(JB.NE.14)) GO TO 36                           PTIP-314
      COR=H*H*CMU(K)/12.D0                                              PTIP-315
      Z1=COR*VA(1,JB-12)                                                PTIP-316
      Y1=COR*VA(2,JB-12)                                                PTIP-317
      IF ((Z1.EQ.0.).AND.(Y1.EQ.0.)) GO TO 36                           PTIP-318
      DO 35 I=1,INM                                                     PTIP-319
      VD(I,IG)=VD(I,IG)-(Z1*VT(I,IH)-Y1*VT(I,IH+1))/VS(I,2)             PTIP-320
   35 VD(I,IG+1)=VD(I,IG+1)-(Z1*VT(I,IH+1)+Y1*VT(I,IH))/VS(I,2)         PTIP-321
   36 Z1=BB(JJ)*XX(1,JB)                                                PTIP-322
      Y1=BB(JJ)*XX(2,JB)                                                PTIP-323
      DO 37 I=1,INM                                                     PTIP-324
      VD(I,IG)=VD(I,IG)+Z1*VT(I,IE)-Y1*VT(I,IE+1)                       PTIP-325
   37 VD(I,IG+1)=VD(I,IG+1)+Z1*VT(I,IE+1)+Y1*VT(I,IE)                   PTIP-326
   38 CONTINUE                                                          PTIP-327
   39 CONTINUE                                                          PTIP-328
      IF (.NOT.LOO(1)) GO TO 40                                         PTIP-329
      LOO(2)=.NOT.LOO(2)                                                PTIP-330
      IF (LOO(2)) GO TO 10                                              PTIP-331
   40 CONTINUE                                                          PTIP-332
   41 CONTINUE                                                          PTIP-333
   42 IF (.NOT.LO(16)) RETURN                                           PTIP-334
C COULOMB INTERACTION                                                   PTIP-335
      IF (LO(7)) RETURN                                                 PTIP-336
      I=NT                                                              PTIP-337
      IF (LO(22)) I=I+2                                                 PTIP-338
      IF (I.GT.4) I=4                                                   PTIP-339
      CCA=CA*CCO(I)                                                     PTIP-340
      IF (CCA.EQ.0.) RETURN                                             PTIP-341
      I=INM                                                             PTIP-342
      VT(I,5)=0.D0                                                      PTIP-343
      VT(I,6)=0.D0                                                      PTIP-344
      DO 43 L=2,INM                                                     PTIP-345
      VT(I-1,5)=VT(I,5)+AM(I,1,KR)*VT(I,1)                              PTIP-346
      VT(I-1,6)=VT(I,6)+AM(I,1,KR)*VT(I,2)                              PTIP-347
   43 I=I-1                                                             PTIP-348
      Z1=0.D0                                                           PTIP-349
      Y1=0.D0                                                           PTIP-350
      COR=H*H/12.D0                                                     PTIP-351
      DO 44 I=1,INM                                                     PTIP-352
      Z1=Z1+AM(I,2,KR)*VT(I,1)                                          PTIP-353
      Y1=Y1+AM(I,2,KR)*VT(I,2)                                          PTIP-354
      CCR=COR/VS(I,2)                                                   PTIP-355
      VD(I,1)=VD(I,1)+CCA*(VT(I,5)*AM(I,2,KR)+Z1*AM(I,1,KR)-VT(I,1)*CCR)PTIP-356
   44 VD(I,2)=VD(I,2)+CCA*(VT(I,6)*AM(I,2,KR)+Y1*AM(I,1,KR)-VT(I,2)*CCR)PTIP-357
      CCO(5)=CCO(5)+CCA*Z1*AM(INM,1,KR)                                 PTIP-358
      RETURN                                                            PTIP-359
      END                                                               PTIP-360
