C 01/12/98                                                      DWBB98  SCAT-000
      SUBROUTINE SCAT(FR,MF,JM,THETA,CMB,NCO,COE,AB,A,B,EX,WV,JX,XZ,LO) SCAT-001
                                                                        SCAT-002
C COMPUTATION OF OBSERVABLES                                            SCAT-003
C INPUT VARIABLES: FR:    SCATTERING COEFF. IN THE HELICITY FORMALISM   SCAT-004
C                  MF:    TABLES OF HELICITY,DESCRIPTION OF OBSERVABLES,SCAT-005
C                         .... ETC   SEE DEPH AND OBSE                  SCAT-006
C                  JM:    DIMENSION FOR FR                              SCAT-007
C                  THETA: SCATTERING ANGLE                              SCAT-008
C                  CMB:   ATOMIC MASS UNIT DIVIDED BY HBAR              SCAT-009
C                  NCO,COE:   LOOPS AND COEFF. FOR OBSERVABLES  SEE OBSESCAT-010
C                  SP:    SPINS FOR INCIDENT AND TARGET NUCLEUS         SCAT-011
C                  WV:    MASSES, ENERGIES, ETC..    SEE CALX           SCAT-012
C                  JX:    TWICE MINIMUM OF THE TOTAL SPIN               SCAT-013
C                  XZ:    CONVERSION FACTOR TO MILLIBARNS               SCAT-014
C                  LO(1): LOGICAL CONTROLS: RELATIVISTIC KINEMATICS     SCAT-015
C                  LO(2): .FALSE. FOR CENTER OF MASS SYSTEM             SCAT-016
C OUTPUT VARIABLES:EX:    DIFFER. CROSS-SECTION FOLLOWED BY OBSERVABLES SCAT-017
C WORKING SPACE:   AB:    AMPLITUDES IN THE C. M. OR THE LAB. SYSTEM    SCAT-018
C                  A:     FOR INDEPENDENT AMPLITUDES                    SCAT-019
C                  B:     TO STORE THE ROTATION MATRIX ELEMENTS         SCAT-020
C OTHER INPUT BY COMMON /RESC/                                          SCAT-021
C                  XA,XB:  CONSTANTS FOR CHANGE TO LABORATORY SYSTEM    SCAT-022
C                  MTT:    TOTAL NUMBER OF AMPLITUDES                   SCAT-023
C BY COMMON /QUAN/ IJ2:    MULTIPLICITY OF THE RESIDUAL TARGET          SCAT-024
C                  IJ1:    MULTIPLICITY OF THE INITIAL TARGET           SCAT-025
C***********************************************************************SCAT-026
      IMPLICIT REAL*8 (A-H,O-Z)                                         SCAT-027
      LOGICAL LO(5),LTT(6),LXY                                          SCAT-028
      DIMENSION FR(2,JM,1),MF(9,1),NCO(20,1),COE(1),AB(2,2,1),A(2,1),B(2SCAT-029
     1),EX(2),WV(6,2),MO(18)                                            SCAT-030
      EQUIVALENCE (MO(1),MI1),(MO(2),MP1),(MO(3),N1),(MO(4),L1),(MO(5),MSCAT-031
     1I2),(MO(6),MP2),(MO(7),N2),(MO(8),L2),(MO(9),MI3),(MO(10),MP3),(MOSCAT-032
     2(11),N3),(MO(12),L3),(MO(13),MI4),(MO(14),MP4),(MO(15),N4),(MO(16)SCAT-033
     3,L4),(MO(17),JQ),(MO(18),JP)                                      SCAT-034
      COMMON /RESC/ XA,XB,MTT                                           SCAT-035
      COMMON /QUAN/ IJ1,IJ2,IP1,IP2,IP3,LML,LMJ,IP4,KY,KC1,KCC,JT,NJY   SCAT-036
      THET=1.74532925D-02*THETA                                         SCAT-037
C FOR EXPERIMENTAL DATA OR EQUIDISTANT ANGLES                           SCAT-038
      W6=DCOS(THET)                                                     SCAT-039
      W7=DSIN(THET)                                                     SCAT-040
      IF (.NOT.LO(2)) GO TO 1                                           SCAT-041
      XC=(XA**2-XB**2)*W7**2+W6**2                                      SCAT-042
      IF (XC.GT.0.D0) XC=DSQRT(XC)                                      SCAT-043
      A3=XC*W6-XA*XB*W7**2                                              SCAT-044
      W7=W7*(XB*W6+XC*XA)                                               SCAT-045
      W6=A3                                                             SCAT-046
C DIRECT INTERACTION CONTRIBUTION                                       SCAT-047
    1 W3=1.D0                                                           SCAT-048
      X2=DSQRT(.5D0*(1.D0+W6))                                          SCAT-049
      X3=DSQRT(.5D0*(1.D0-W6))                                          SCAT-050
      DO 2 I=1,KY                                                       SCAT-051
      A(1,I)=0.D0                                                       SCAT-052
    2 A(2,I)=0.D0                                                       SCAT-053
      IF (IP3.NE.1) GO TO 4                                             SCAT-054
C COMPUTATION OF COULOMB AMPLITUDES FOR THE ELASTIC CHANNEL             SCAT-055
      IF (WV(4,1).EQ.0..OR.X3.LT.1.E-20) GO TO 4                        SCAT-056
      W2=2.D0*WV(4,1)*DLOG(X3)                                          SCAT-057
      W3=-0.5D0*WV(4,1)/(X3*X3)                                         SCAT-058
      W4=W3*DCOS(W2)                                                    SCAT-059
      W5=-W3*DSIN(W2)                                                   SCAT-060
      W3=W3**2                                                          SCAT-061
C TRANSFORMATION OF THE COULOMB AMPLITUDES TO THE HELICITY FORMALISM    SCAT-062
      DO 3 I=1,KY                                                       SCAT-063
      CALL EMRO(1,2*MF(3,I)-3,2*MF(1,I)-3,X2,X3,B,1)                    SCAT-064
      CALL EMRO(IJ2-1,IJ2+1-2*MF(4,I),IJ2+1-2*MF(2,I),X2,X3,B(2),1)     SCAT-065
      W1=B(1)*B(2)                                                      SCAT-066
      A(1,I)=W4*W1                                                      SCAT-067
    3 A(2,I)=W5*W1                                                      SCAT-068
      W3=W3/WV(3,1)**2                                                  SCAT-069
C COMPUTATION OF THE NUCLEAR AMPLITUDES                                 SCAT-070
    4 DO 8 I=1,KY                                                       SCAT-071
      W5=1.D0                                                           SCAT-072
      IF (IABS(MF(7,I)).EQ.10000) GO TO 5                               SCAT-073
      CALL EMRO(JX,MF(6,I),MF(7,I),X2,X3,B,JM)                          SCAT-074
      W1=W5                                                             SCAT-075
      GO TO 6                                                           SCAT-076
C ROTATION MATRIX ELEMENTS ARE THE SAME AS FOR THE LAST AMPLITUDE       SCAT-077
    5 W1=W5*MF(7,I)/IABS(MF(7,I))                                       SCAT-078
    6 DO 7 J=1,JM                                                       SCAT-079
      A(1,I)=A(1,I)+FR(1,J,I)*W1*B(J)                                   SCAT-080
    7 A(2,I)=A(2,I)+FR(2,J,I)*W1*B(J)                                   SCAT-081
C CONSTRUCTION OF THE TOTAL AMPLITUDE MATRIX                            SCAT-082
      K1=MF(8,I)                                                        SCAT-083
      AB(1,K1,1)=A(1,I)                                                 SCAT-084
      AB(2,K1,1)=A(2,I)                                                 SCAT-085
      IF (MF(5,I).EQ.0) GO TO 8                                         SCAT-086
      K1=MF(9,I)                                                        SCAT-087
      AB(1,K1,1)=MF(5,I)*A(1,I)                                         SCAT-088
      AB(2,K1,1)=MF(5,I)*A(2,I)                                         SCAT-089
    8 CONTINUE                                                          SCAT-090
C CROSS-SECTION                                                         SCAT-091
      DZ=0.D0                                                           SCAT-092
      DO 9 I1=1,MTT                                                     SCAT-093
    9 DZ=DZ+AB(1,I1,1)*AB(1,I1,1)+AB(2,I1,1)*AB(2,I1,1)                 SCAT-094
      EX(1)=DZ*XZ                                                       SCAT-095
      LX1=0                                                             SCAT-096
      LX2=0                                                             SCAT-097
      JEX=1                                                             SCAT-098
C LOOP ON THE OBSERVABLES                                               SCAT-099
      DO 49 IEX=KC1,KCC                                                 SCAT-100
      JEX=JEX+1                                                         SCAT-101
      IF (MF(1,IEX).GT.1) GO TO 16                                      SCAT-102
      IF (MF(1,IEX)) 12 , 10 , 11                                       SCAT-103
C CROSS SECTION                                                         SCAT-104
   10 EX(JEX)=EX(1)                                                     SCAT-105
      GO TO 49                                                          SCAT-106
C CROSS SECTION DIVIDED BY RUTHERFORD'S CROSS-SECTION                   SCAT-107
   11 EX(JEX)=EX(1)/(10.D0*W3)                                          SCAT-108
      GO TO 49                                                          SCAT-109
   12 EX(JEX)=0.D0                                                      SCAT-110
      IF (MF(1,IEX).EQ.-3) GO TO 14                                     SCAT-111
      MTP=2*IJ1*IJ2                                                     SCAT-112
C VECTOR ANALYSING POWER FOR SPIN 1/2                                   SCAT-113
      DO 13 I1=1,MTP                                                    SCAT-114
      I2=I1+MTP                                                         SCAT-115
   13 EX(JEX)=EX(JEX)+AB(2,I2,1)*AB(1,I1,1)-AB(1,I2,1)*AB(2,I1,1)       SCAT-116
      EX(JEX)=2.D0*EX(JEX)*XZ/EX(1)                                     SCAT-117
      GO TO 49                                                          SCAT-118
C VECTOR POLARISATION FOR SPIN 1/2                                      SCAT-119
   14 DO 15 I1=1,MTT,2                                                  SCAT-120
   15 EX(JEX)=EX(JEX)+AB(1,I1+1,1)*AB(2,I1,1)-AB(2,I1+1,1)*AB(1,I1,1)   SCAT-121
      EX(JEX)=2.D0*EX(JEX)*XZ/EX(1)                                     SCAT-122
      GO TO 49                                                          SCAT-123
C ALL THE OTHER OBSERVABLES                                             SCAT-124
   16 EX(JEX)=0.D0                                                      SCAT-125
      K1=MF(3,IEX)                                                      SCAT-126
      K2=MF(4,IEX)                                                      SCAT-127
C LOOP ON THE COMPONENTS OF THE DESCRIPTION OF THE OBSERVABLE           SCAT-128
      DO 48 II=K1,K2                                                    SCAT-129
      IX=1                                                              SCAT-130
      IXY=1                                                             SCAT-131
      IXX=IXY+IJ2*2*IJ1                                                 SCAT-132
      DO 17 I=1,18                                                      SCAT-133
   17 MO(I)=NCO(I,II)                                                   SCAT-134
      DO 18 IJ=1,6                                                      SCAT-135
      LTT(IJ)=MOD(JQ,2).EQ.1                                            SCAT-136
   18 JQ=JQ/2                                                           SCAT-137
C COMPUTATION OF THE ANGLE FOR A CHANGE OF FRAME                        SCAT-138
      IF (MOD(JP,1000).EQ.0) GO TO 41                                   SCAT-139
      LXY=.TRUE.                                                        SCAT-140
      IF (LX1.EQ.MOD(JP,1000)) GO TO 40                                 SCAT-141
      LX1=MOD(JP,1000)                                                  SCAT-142
      LX2=0                                                             SCAT-143
      N=2                                                               SCAT-144
      IF (LX1.EQ.1) GO TO 21                                            SCAT-145
      GO TO 20                                                          SCAT-146
   19 IF (JP/1000.EQ.0) GO TO 41                                        SCAT-147
      LXY=.FALSE.                                                       SCAT-148
      IF (JP/1000.EQ.LX2) GO TO 40                                      SCAT-149
      LX2=JP/1000                                                       SCAT-150
      N=IJ2                                                             SCAT-151
      IF (LX2.EQ.1) GO TO 22                                            SCAT-152
   20 IF (DABS(W7).LT.1.D-5.OR.N.EQ.1) GO TO 38                         SCAT-153
      W1=W6                                                             SCAT-154
      W2=-W7                                                            SCAT-155
      GO TO 26                                                          SCAT-156
C TRANSFORMATION TO THE LABORATORY SYSTEM FOR THE PARTICLE              SCAT-157
   21 W1=WV(1,2)                                                        SCAT-158
      GO TO 23                                                          SCAT-159
C TRANSFORMATION TO THE LABORATORY SYSTEM FOR THE TARGET                SCAT-160
   22 W1=-WV(2,2)                                                       SCAT-161
   23 IF (N.EQ.1) GO TO 38                                              SCAT-162
      IF (.NOT.LO(1)) GO TO 24                                          SCAT-163
      W1=WV(3,2)/(CMB*W1)                                               SCAT-164
      W2=CMB*WV(2,1)/WV(3,1)                                            SCAT-165
      W3=DATAN(-W7/(W6*DSQRT(W1*W1+1.D0)+W1*DSQRT(W2*W2+1.D0)))         SCAT-166
      GO TO 25                                                          SCAT-167
   24 W3=DATAN(-W7/(WV(3,2)*WV(2,1)/(WV(3,1)*W1)+W6))                   SCAT-168
   25 IF (DABS(W3).LT.1.D-5.OR.N.EQ.1) GO TO 38                         SCAT-169
      W1=DCOS(W3)                                                       SCAT-170
      W2=DSIN(W3)                                                       SCAT-171
   26 DO 27 I=1,MTT                                                     SCAT-172
      AB(1,I,IXX)=0.D0                                                  SCAT-173
   27 AB(2,I,IXX)=0.D0                                                  SCAT-174
      W3=DSQRT(.5D0*(1.D0-W1))                                          SCAT-175
      W5=1.D0                                                           SCAT-176
      DO 28 I=2,N                                                       SCAT-177
   28 W5=-W5*W3                                                         SCAT-178
      IF (DABS(W5).LT.1.D-30) GO TO 38                                  SCAT-179
      W4=0.D0                                                           SCAT-180
      W8=.5D0*(N-1)                                                     SCAT-181
      MTY=2*IJ1                                                         SCAT-182
      X3=-W8                                                            SCAT-183
C TRANSFORMATION OF THE AMPLITUDE MATRIX                                SCAT-184
      DO 37 I=1,N                                                       SCAT-185
      IF (I.EQ.1) GO TO 29                                              SCAT-186
      W3=W4                                                             SCAT-187
      IF (I.NE.2) W3=W3*DSQRT(DFLOAT((I-2)*(N+2-I)))                    SCAT-188
      W4=W5                                                             SCAT-189
      W5=(2.D0*(X3*W1-W8)*W4/W2-W3)/DSQRT(DFLOAT((I-1)*(N+1-I)))        SCAT-190
      X3=X3+1.D0                                                        SCAT-191
   29 X2=0.D0                                                           SCAT-192
      X5=W5                                                             SCAT-193
      X4=W8                                                             SCAT-194
      DO 36 J=I,N                                                       SCAT-195
      IF (J.EQ.I) GO TO 30                                              SCAT-196
      X1=X2                                                             SCAT-197
      IF (J.NE.I+1) X1=X1*DSQRT(DFLOAT((J-I-1)*(N+1-J+I)))              SCAT-198
      X2=X5                                                             SCAT-199
      X5=(2.D0*(X3-X4*W1)*X2/W2-X1)/DSQRT(DFLOAT((J-I)*(N+I-J)))        SCAT-200
      X4=X4-1.D0                                                        SCAT-201
   30 X=X5                                                              SCAT-202
      L=1+J-I                                                           SCAT-203
      M=N+1-I                                                           SCAT-204
      DO 35 K=1,2                                                       SCAT-205
      DO 34 I1=1,MTY                                                    SCAT-206
      IF (LXY) GO TO 32                                                 SCAT-207
      IXI=IXX+(I1-1)*IJ2+L-1                                            SCAT-208
      IXJ=IXY+(I1-1)*IJ2+M-1                                            SCAT-209
      DO 31 I4=1,2                                                      SCAT-210
      AB(1,I4,IXI)=AB(1,I4,IXI)+X*AB(1,I4,IXJ)                          SCAT-211
   31 AB(2,I4,IXI)=AB(2,I4,IXI)+X*AB(2,I4,IXJ)                          SCAT-212
      GO TO 34                                                          SCAT-213
   32 IXI=2*(IXX+(I1-1)*IJ2-1)+L                                        SCAT-214
      IXJ=2*(IXY+(I1-1)*IJ2-1)+M                                        SCAT-215
      DO 33 I4=1,IJ2                                                    SCAT-216
      AB(1,IXI,I4)=AB(1,IXI,I4)+X*AB(1,IXJ,I4)                          SCAT-217
   33 AB(2,IXI,I4)=AB(2,IXI,I4)+X*AB(2,IXJ,I4)                          SCAT-218
   34 CONTINUE                                                          SCAT-219
      IF (J.EQ.N) GO TO 36                                              SCAT-220
      ML=L                                                              SCAT-221
      L=M                                                               SCAT-222
      M=ML                                                              SCAT-223
      IF (MOD(J+N,2).NE.0) X=-X                                         SCAT-224
   35 CONTINUE                                                          SCAT-225
   36 CONTINUE                                                          SCAT-226
   37 CONTINUE                                                          SCAT-227
      GO TO 40                                                          SCAT-228
   38 DO 39 I=1,MTT                                                     SCAT-229
      AB(1,I,IXX)=AB(1,I,IXY)                                           SCAT-230
   39 AB(2,I,IXX)=AB(2,I,IXY)                                           SCAT-231
   40 IX=IX+1                                                           SCAT-232
      IXY=IXX                                                           SCAT-233
      IXX=IXY+IJ2*2*IJ1                                                 SCAT-234
      IF (LXY) GO TO 19                                                 SCAT-235
   41 IF (LTT(5)) GO TO 47                                              SCAT-236
      X=0.D0                                                            SCAT-237
C THE FOUR DO LOOPS                                                     SCAT-238
      DO 46 I1=MI1,MP1                                                  SCAT-239
      J1=I1-N1                                                          SCAT-240
      X1=COE(10*II)                                                     SCAT-241
      IF (LTT(1)) X1=COE(10*II)*COE(I1+L1)                              SCAT-242
      DO 45 I2=MI2,MP2                                                  SCAT-243
      J2=I2-N2                                                          SCAT-244
      X2=X1                                                             SCAT-245
      IF (LTT(2)) X2=X1*COE(L2-I2)                                      SCAT-246
      DO 44 I3=MI3,MP3                                                  SCAT-247
      J3=I3-N3                                                          SCAT-248
      X3=X2                                                             SCAT-249
      IF (LTT(3)) X3=X2*COE(I3+L3)                                      SCAT-250
      DO 43 I4=MI4,MP4                                                  SCAT-251
      J4=I4-N4                                                          SCAT-252
      X4=X3                                                             SCAT-253
      IIJ=I4+IJ2*(J2-1+IJ1*(J1-1+2*(IX-1)))                             SCAT-254
      III=J4+IJ2*(I2-1+IJ1*(I1-1+2*(IX-1)))                             SCAT-255
      IF (LTT(4)) X4=X3*COE(L4-I4)                                      SCAT-256
      IF (LTT(6)) GO TO 42                                              SCAT-257
      X=X+(AB(1,I3,IIJ)*AB(1,J3,III)+AB(2,I3,IIJ)*AB(2,J3,III))*X4      SCAT-258
      GO TO 43                                                          SCAT-259
   42 X=X+(AB(2,I3,IIJ)*AB(1,J3,III)-AB(1,I3,IIJ)*AB(2,J3,III))*X4      SCAT-260
   43 CONTINUE                                                          SCAT-261
   44 CONTINUE                                                          SCAT-262
   45 CONTINUE                                                          SCAT-263
   46 CONTINUE                                                          SCAT-264
      GO TO 48                                                          SCAT-265
   47 X=COE(10*II)*DZ                                                   SCAT-266
   48 EX(JEX)=EX(JEX)+X                                                 SCAT-267
      EX(JEX)=EX(JEX)/DZ                                                SCAT-268
   49 CONTINUE                                                          SCAT-269
      IF (.NOT.LO(2)) RETURN                                            SCAT-270
      XC=DSQRT((XA*W6+XB)**2+W7**2)**3/DABS(XA+XB*W6)                   SCAT-271
      EX(1)=EX(1)*XC                                                    SCAT-272
      EX(2)=EX(2)*XC                                                    SCAT-273
      RETURN                                                            SCAT-274
      END                                                               SCAT-275
